import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Medical Advisor related titles

medical_advisor_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bMedical\s?Advisor\b",
    r"(?i)\bMedical\s?Affairs\s?Advisor\b",
    r"(?i)\bHealthcare\s?Advisor\b",
    r"(?i)\bMedical\s?Affairs\s?Specialist\b",
    r"(?i)\bScientific\s?Advisor\b",
    r"(?i)\bClinical\s?Advisor\b",
    r"(?i)\bSenior\s?Medical\s?Advisor\b",
    r"(?i)\bChief\s?Medical\s?Advisor\b",
    r"(?i)\bMedical\s?Affairs\s?Manager\b",
    r"(?i)\bHead Of Advisory\b",
    r"(?i)\bPhysician Liason\b",
    r"(?i)\bApprentice Medical Communication\b",
    r"(?i)\bMsd\b",
    r"(?i)\bScience Executive Advisor\b",
    r"(?i)\bSenior Regulatory Advisor\b",

    # Misspellings & Typographical Errors
    r"(?i)\bMedcial\s?Advisor\b",
    r"(?i)\bMediacl\s?Advisor\b",
    r"(?i)\bMedical\s?Advisr\b",
    r"(?i)\bMedical\s?Advissor\b",
    r"(?i)\bMedical\s?Advisro\b",
    r"(?i)\bMedcial\s?Advisr\b",
    r"(?i)\bMedical\s?Advizeor\b",
    r"(?i)\bMedicall\s?Advisor\b",
    r"(?i)\bMedical\s?Advisour\b",
    r"(?i)\bMedical\s?Adviosr\b",

    # Case Variations
    r"(?i)\bmedical advisor\b",
    r"(?i)\bMedical advisor\b",
    r"(?i)\bmedical Advisor\b",
    r"(?i)\bMEDICAL ADVISOR\b",
    r"(?i)\bMedIcal AdvIsor\b",

    # Spanish Variants
    r"(?i)\bAsesor\s?Médico\b",
    r"(?i)\bEspecialista\s?en\s?Asuntos\s?Médicos\b",
    r"(?i)\bConsejero\s?Médico\b",
    r"(?i)\bDirector\s?Médico\s?Consultor\b",
    r"(?i)\bGestor\s?de\s?Asuntos\s?Médicos\b",
    r"(?i)\bAsesor\s?de\s?Salud\b",

    # Other Possible Variations (Including Doctor/Specialist Titles)
    r"(?i)\bMedical\s?Director\b",
    r"(?i)\bMedical\s?Strategy\s?Advisor\b",
    r"(?i)\bRegulatory\s?Medical\s?Advisor\b",
    r"(?i)\bPharmaceutical\s?Advisor\b",
    r"(?i)\bDrug\s?Safety\s?Advisor\b",
    r"(?i)\bClinical\s?Regulatory\s?Advisor\b",
    r"(?i)\bSenior\s?Medical\s?Consultant\b",
    r"(?i)\bGlobal\s?Medical\s?Advisor\b",
    r"(?i)\bHealth\s?Policy\s?Advisor\b",
    r"(?i)\bHealthcare\s?Regulatory\s?Advisor\b",
    r"(?i)\bMedical Affairs Lead\b",
]

# Exact matches that should be updated
medical_advisor_exact_matches = {
    "Medical Advisor",
    "Medical Affairs Advisor",
    "Healthcare Advisor",
    "Medical Affairs Specialist",
    "Scientific Advisor",
    "Clinical Advisor",
    "Senior Medical Advisor",
    "Chief Medical Advisor",
    "Medical Affairs Manager",
    "Medcial Advisor",
    "Mediacl Advisor",
    "Medical Advisr",
    "Medical Advissor",
    "Medical Advisro",
    "Medcial Advisr",
    "Medical Advizeor",
    "Medicall Advisor",
    "Medical Advisour",
    "Medical Adviosr",
    "Asesor Médico",
    "Especialista en Asuntos Médicos",
    "Consejero Médico",
    "Director Médico Consultor",
    "Gestor de Asuntos Médicos",
    "Asesor de Salud",
    "Medical Director",
    "Medical Strategy Advisor",
    "Regulatory Medical Advisor",
    "Pharmaceutical Advisor",
    "Drug Safety Advisor",
    "Clinical Regulatory Advisor",
    "Senior Medical Consultant",
    "Global Medical Advisor",
    "Health Policy Advisor",
    "Healthcare Regulatory Advisor",
    "Surgical Equipment",
    'Advisor',
    'Adviser',
    'Director Of Medical Supply',
    'Program Manager Health Public & Government Affairs',
    'Medicina Estrategica',
    'Director II Skincare Clinical Development & Medical Affairs',
    'Global Medical Advocacy',
    'HCP Advocacy',
    'MEDICA',
    'MEDICO',
    'MSL',
    'Medical Affairs Clinician',
    'Medical Science Liaison Skincare',
    'Physician Advisor',
    'Certified Dermatology Coder',
    'Dermatology Medical Affairs Head Us',
    'Director Field Medical Dermatology',
    'Director Medical Affairs Dermatology Us',
    'Medical Science Dermatology & Iai Liaison',
    'Medical Science Executive & Dermatology Immunology Liaison',
    'Director Medical Affairs',
    'Director Medical Affairs Clinical & Medical Affairs',
    'Medical Affairs',
    'Sr  Director Medical Affairs',
    'Associate Medical Affair Advisor - Neuromodulators',
    'DMP',
}

# Define patterns (these should NOT be changed)
medical_advisor_exclusions = r'\b(?:Plastic)|(?:Physician)|(?:Neonatology)\b'

# Create a mask for Medical Advisor
mask_medical_advisor = df['speciality'].str.contains('|'.join(medical_advisor_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(medical_advisor_exact_matches)
mask_medical_advisor_exclusions = df['speciality'].str.contains(medical_advisor_exclusions, case=False, na=False, regex=True)

# Final mask: Select Medical Advisor
mask_medical_advisor_final = mask_medical_advisor & ~mask_medical_advisor_exclusions

# Store the original values that will be replaced
original_medical_advisor_values = df.loc[mask_medical_advisor_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_medical_advisor_final, 'speciality'] = 'Medical Advisor'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Medical Advisor", 'green'))
print(df.loc[mask_medical_advisor_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_medical_advisor_values = df.loc[mask_medical_advisor_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Medical Advisor", "cyan"))
for original_medical_advisor_value in original_medical_advisor_values:
    print(f"✅ {original_medical_advisor_value} → Medical Advisor")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Medical Advisor:", 'red'))
print(grouped_medical_advisor_values)

# Print summary
matched_count_medical_advisor = mask_medical_advisor_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Medical Advisor: "
        f"{matched_count_medical_advisor}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Lawyer related titles

lawyer_variants = [
    r"(?i)\bLawyer\b",
    r"(?i)\bAttorney\b",
    r"(?i)\bLegal\s?Advisor\b",
    r"(?i)\bSolicitor\b",

    # Common misspellings and case errors
    r"(?i)\bLwyer\b",
    r"(?i)\bLawer\b",
    r"(?i)\bLoyer\b",
    r"(?i)\bAtorney\b",
    r"(?i)\bAttorny\b",

    # Spanish variants
    r"(?i)\bAbogado\b",
    r"(?i)\bAbogada\b",
    r"(?i)\bAbogado/a\b",
    r"(?i)\bAbogado/a de defensa\b",
    r"(?i)\bAbogado/a corporativo\b",
    r"(?i)\bLicenciado en Derecho\b",

    # Other possible variations
    r"(?i)\bCriminal\s?Lawyer\b",
    r"(?i)\bCivil\s?Lawyer\b",
    r"(?i)\bCorporate\s?Lawyer\b",
    r"(?i)\bFamily\s?Lawyer\b",
    r"(?i)\bPersonal\s?Injury\s?Lawyer\b",
    r"(?i)\bLaw\b",
]

# Exact matches that should be updated
lawyer_exact_matches = {
    "Lawyer",
    "Attorney",
    "Legal Advisor",
    "Solicitor",
    # Misspellings
    "Lwyer",
    "Lawer",
    "Loyer",
    "Atorney",
    "Attorny",
    # Spanish variants
    "Abogado",
    "Abogada",
    "Abogado/a",
    "Abogado/a de defensa",
    "Abogado/a corporativo",
    "Licenciado en Derecho",
    # Other possible variations
    "Criminal Lawyer",
    "Civil Lawyer",
    "Corporate Lawyer",
    "Family Lawyer",
    "Personal Injury Lawyer",
}

# Define patterns (these should NOT be changed)
lawyer_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Lawyer
mask_lawyer = df['speciality'].str.contains('|'.join(lawyer_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(lawyer_exact_matches)
mask_lawyer_exclusions = df['speciality'].isin(lawyer_exclusions)

# Final mask: Select Lawyer
mask_lawyer_final = mask_lawyer & ~mask_lawyer_exclusions

# Store the original values that will be replaced
original_lawyer_values = df.loc[mask_lawyer_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_lawyer_final, 'speciality'] = 'Lawyer'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Lawyer", 'green'))
print(df.loc[mask_lawyer_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_lawyer_values = df.loc[mask_lawyer_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Lawyer", "cyan"))
for original_lawyer_value in original_lawyer_values:
    print(f"✅ {original_lawyer_value} → Lawyer")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Lawyer:", 'red'))
print(grouped_lawyer_values)

# Print summary
matched_count_lawyer = mask_lawyer_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Lawyer: "
        f"{matched_count_lawyer}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

df['speciality'] = df['speciality'].apply(normalize_text)  # Apply normalization

# Define regex patterns for ARNP-related titles (excluding RN, BSN)
arnp_variants = [
    r'\b(?:Arnp|Aprn|Advance Practice Nurse Practitioner|Aprn-Cnp|Fnp-Bc|Crna|Dnp|Rnc-Tnp|Enp|Crnp)\b',
    r'\b(?:Master Injector|Regenerative Med|Medspa Owner|Wellness Professional)\b',
    r'\b(?:Cosmetic Injector)\b',
    r'\b(?:Nurse \(Registered - Arnp\))\b',  # Ensures exact match
    r"(?i)\bARNP\b",
    r"(?i)\bAdvanced Registered Nurse Practitioner\b",
    r"(?i)\bArpn\b",
    r"(?i)\bArpn\b",
    r"(?i)\bAesthetic Nourse\b",
    r"(?i)\bAesthetic PracticionerNurse\b",
    r"(?i)\bCosmetic Injecting Nurse\b",
    r"(?i)\bDermatology Nurse\b",
    r"(?i)\bSkin TherapistNurse Dermatology\b",
    r"(?i)\bAdvanced Practice Registered Nurse\b",
    r"(?i)\bNurse Aesthetic\b",
    r"(?i)\bNurses\b",
    r"(?i)\bCnp\b",
    r"(?i)\bNurse Injector\b",
    r"(?i)\bNurse InjectorLaser\b",
]

# Exact matches that should be updated
arnp_exact_matches = {
    'Nurse (Registered - Arnp)',
    'Arnp',
    'Aprn',
    'Crna Injector',
    'Aprn Fnp-Bc',
    'Dnp Bsb Aprn Fnp-C Rnc-Tnp',
    'Mn Aprn Fnp-C',
    'Dnp Arnp',
    'Aprn Crna',
    'Advanced Registered Nurse Practitioner',
    'Advanced Nurse Practitioner',
    'Registered Nurse (ARNP)',
    'Registered Nurse Practitioner (ARNP)',
    'ARNP-C',
    'ARNP-FNP',
    'FNP-BC',
    'CRNA',
    'CRNA Injector',
    'Certified Nurse Practitioner',
    'Certified Advanced Practice Nurse',
    'Certified Nurse Midwife',
    'Nurse Practitioner (ARNP)',
    'Family Nurse Practitioner (ARNP)',
    'Adult Nurse Practitioner (ARNP)',
    'Pediatric Nurse Practitioner (ARNP)',
    'Psychiatric Nurse Practitioner (ARNP)',
    'Acute Care Nurse Practitioner (ARNP)',
    'Doctor of Nursing Practice (DNP)',
    'Doctor of Nursing Practice - APRN',
    'Doctorate APRN', 'DNP-ARNP',
    'Nurse Practitioner (APRN)',
    'Advanced Practice Registered Nurse (APRN)',
    'Nurse Anesthetist (CRNA)',
    'CRNA Nurse Injector',
    'APRNs',
    'APRN-CNP',
    'APRN-FNP',
    'FNP-BC APRN',
    'APRN-C',
    'Nurse Aesthetic Practitioner',
# Variations for common typos and case mistakes
    'Advanced Nurse Practitionar',
    'Adanced Nurse Practitioner',
    'Advaned Nurse Practitioner',
    'Arnp-CRNA',
    'Arnp-Crna',
    'APRN-Cnp',
    'Aprn-fnp',
    'APRN-Fnp',
    'Aprn-Fnp',
    'Doctor of Nursing Practce',
    'Doctorate APR',
    'Family Nurse Practioner (ARNP)',
    'Nurse Practioner (APRN)',
    'Nurse Anestheist (CRNA)',
    'FNP-BC',
    'Advanced Practiced Registered Nurse',
    'Advanced Practice Registered Nuse',
    'Advanced Nurse Practitoner',
    'Advanced Nursing Practitoner',
    'APRN Nurse',
    'APRN Nurse Practitioner',
    'Adanced Registered Nurse Practitioner',
    'Advanced Nurse Practicinor',
    'Advaneced Nurse Practitioner',
    'Nurse Practicianer (ARNP)',
    'Certified Nuse Practicioner',
    'A.D.N Nurse Practitioner',
    'Nurse Praticioner (ARNP)',
    'Advanced Nurse Practicioner (ARNP)',
    'Advanced Registered Nurse Practicioner (ARNP)',
    'Aesthetics Nurse',
    'Aesthetics NursePrescriber',
    'Aesthetic Nurse Specialist',
    'Aesthete Nurse',
    'NPNurse Injector',
    'AESTHETIC NURSE',
    'Advanced Practice Aesthetic RN',
    'Medical Aesthetics Nurse',
    'Dermatology Practice Nurse',
    'APN',
    'APN-C',
}

# Define patterns for RN & BSN (these should NOT be changed)
arnp_exclusions = r'\b(?:Rn|Bsn|Registered Nurse(?!\s+Advanced|\s+Practitioner|\s+Practicioner|\s*\()|Licensed Practical Nurse|Lpn)\b'

# Create a mask for ARNP-related terms but exclude RN/BSN
mask_arnp = df['speciality'].str.contains('|'.join(arnp_variants), case=False, na=False, regex=True) | \
            df['speciality'].isin(arnp_exact_matches)
mask_arnp_exclude = df['speciality'].str.contains(arnp_exclusions, case=False, na=False, regex=True)

# Final mask: Select ARNP-related values but exclude RN/BSN
mask_arnp_final = mask_arnp & ~mask_arnp_exclude

# Store the original values that will be replaced
original_arnp_values = df.loc[mask_arnp_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_arnp, 'speciality'] = 'Advanced Registered Nurse Practitioner (ARNP)'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Advanced Registered Nurse Practitioner (ARNP)", 'green'))
print(df.loc[mask_arnp_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_arnp_values = df.loc[mask_arnp_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Advanced Registered Nurse Practitioner (ARNP)", "cyan"))
for original_arnp_value in original_arnp_values:
    print(f"✅ {original_arnp_value} → Advanced Registered Nurse Practitioner (ARNP)")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with ARNP:", 'red'))
print(grouped_arnp_values)

# Print summary
matched_count_arnp = mask_arnp_final.sum()

# Print results
print(colored(f"\nTotal values matched and changed (Stage 1) to Advanced Registered Nurse Practitioner (ARNP): {matched_count_arnp}", 'red'))





import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Employee related titles

employee_variants = [
    r"(?i)\bemployee\b",
    r"(?i)\bemployees\b",
    r"(?i)\bworker\b",
    r"(?i)\bworkers\b",
    r"(?i)\bstaff\s?member\b",
    r"(?i)\bteam\s?member\b",
    r"(?i)\bsubordinate\b",
    r"(?i)\bemployee\s?worker\b",
    r"(?i)\bempleado\b",
    r"(?i)\bempleados\b",
    r"(?i)\btrabajador\b",
    r"(?i)\btrabajadores\b",
    r"(?i)\bmiembro\s?de\s?equipo\b",
    r"(?i)\bcolaborador\b",
    r"(?i)\bsubordinado\b",
    r"(?i)\basociado\b",
    # Misspellings
    r"(?i)\bemplyee\b",
    r"(?i)\bemploye\b",
    r"(?i)\bemployye\b",
    r"(?i)\beployee\b",
    r"(?i)\bempoyee\b",
    r"(?i)\bemloyee\b",
    r"(?i)\bemployee\s?worker\b",
    # Other Possible Variations
    r"(?i)\bfull\s?time\s?employee\b",
    r"(?i)\bpart\s?time\s?employee\b",
    r"(?i)\btemporary\s?employee\b",
    r"(?i)\bpermanent\s?employee\b",
    r"(?i)\bcontract\s?employee\b",
    r"(?i)\bvolunteer\b",
    r"(?i)\bstaff\s?member\b",
    r"(?i)\btemporary\s?worker\b",
    r"(?i)\bWorker\b",
    r"(?i)\bEmployee\b",
    r"(?i)\bTechnical Associate\b",
    r"(?i)\bSecretaire De Direction\b",
    r"(?i)\bDaily Worker\b",
    r"(?i)\bCompany Employee\b",
    r"(?i)\bAs Worker\b",
    r"(?i)\bGovt Employee\b",
    r"(?i)\bAssistant Worker\b",
    r"(?i)\bStaff Member\b",
    r"(?i)\bI Am A Social Worker\b",
    r"(?i)\bGeneral Worker\b",
    r"(?i)\bWorker At Shop\b",
    r"(?i)\bGalderma Employee\b",
    r"(?i)\bInjectables Employee\b",
    r"(?i)\bLaborConstruction Worker\b",
    r"(?i)\bAbbvie Worker\b",
    r"(?i)\bFarm Worker\b",
    r"(?i)\bSocial Worker\b",
    r"(?i)\bPrivate Company Employee\b",
    r"(?i)\bWorkers\b",
]

# Exact matches that should be updated
employee_exact_matches = {
    "Employee",
    "Employees",
    "Worker",
    "Workers",
    "Staff",
    "Team Member",
    "Personnel",
    "Team",
    "Associate",
    "Subordinate",
    "Empleado",
    "Empleados",
    "Trabajador",
    "Trabajadores",
    "Miembro de Equipo",
    "Personal",
    "Colaborador",
    "Subordinado",
    "Asociado",
    "Empllyee",
    "Employe",
    "Employye",
    "Eployee",
    "Empoyee",
    "Emloyee",
    "Employee Worker",
    "Full Time Employee",
    "Part Time Employee",
    "Temporary Employee",
    "Permanent Employee",
    "Contract Employee",
    "Intern",
    "Volunteer",
    "Staff Member",
    "Temporary Worker",
    "Patient/Other",
    'Associate',
    'associate',
    'Direction',
    'direction',
    'staff',
    'Staff',
    'Senior Clerk',
}

# Define patterns (these should NOT be changed)
employee_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Volunteer Professor Of Dermatology',
    'Volunteer Assistant Clinical Professor',
}

# Create a mask for Employee
mask_employee = df['speciality'].str.contains('|'.join(employee_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(employee_exact_matches)
mask_employee_exclusions = df['speciality'].isin(employee_exclusions)

# Final mask: Select Employee
mask_employee_final = mask_employee & ~mask_employee_exclusions

# Store the original values that will be replaced
original_employee_values = df.loc[mask_employee_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_employee_final, 'speciality'] = 'Employee'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Employee", 'green'))
print(df.loc[mask_employee_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_employee_values = df.loc[mask_employee_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Employee", "cyan"))
for original_employee_value in original_employee_values:
    print(f"✅ {original_employee_value} → Employee")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Employee:", 'red'))
print(grouped_employee_values)

# Print summary
matched_count_employee = mask_employee_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Employee: "
        f"{matched_count_employee}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Cosmetologist MD related titles

cosmetologist_md_variants = [
    # Standard title variations
    r"(?i)\bCosmetologist\s?MD\b",
    r"(?i)\bMD\s?Cosmetologist\b",
    r"(?i)\bDoctor\s?of\s?Cosmetology\b",
    r"(?i)\bCosmetic\s?Doctor\b",
    r"(?i)\bMedical\s?Cosmetologist\b",
    r"(?i)\bCosmetologist\b",
    r"(?i)\bCosmiatry\b",
    r"(?i)\bVrach-Kosmetolog\b",
    r"(?i)\bCosmeologist\b",

    # Common misspellings and case mistakes
    r"(?i)\bCosmotologist\s?MD\b",
    r"(?i)\bCosmetoligist\s?MD\b",
    r"(?i)\bCosmetologist\s?M\.?D\.?\b",
    r"(?i)\bCosmatologist\s?MD\b",
    r"(?i)\bMD\s?Cosmotologist\b",

    # Variants in Spanish and other languages
    r"(?i)\bCosmetólogo\s?MD\b",
    r"(?i)\bMédico\s?Cosmetólogo\b",
    r"(?i)\bDoctor\s?en\s?Cosmetología\b",

    # Other possible variations
    r"(?i)\bBoard\s?-?\s?Certified\s?Cosmetologist\s?MD\b",
    r"(?i)\bAesthetic\s?Physician\s?\(Cosmetology\)\b",

    # Standard title variations
    r"(?i)\bCosmetologist\b",
    r"(?i)\bCosmetic\s?Specialist\b",

    # Common misspellings and case mistakes
    r"(?i)\bCosmotologist\b",
    r"(?i)\bCosmetoligist\b",
    r"(?i)\bCosmatologist\b",

    # Variants in Spanish and other languages
    r"(?i)\bCosmetólogo\b",
    r"(?i)\bEspecialista\s?en\s?Cosmetología\b",

    # Other possible variations
    r"(?i)\bProfessional\s?Cosmetologist\b",
    r"(?i)\bLicensed\s?Cosmetologist\b",
    r"(?i)\bCosmetology\b",
    r"(?i)\bCosmetic Medicine\b",
    r"(?i)\bSosmetologist\b",
    r"(?i)\bCosmetologie\b",
    r"(?i)\bArsthetician Cosemtologist\b",
    r"(?i)\bKosmetolog Feldsher\b",
]

# Exact matches that should be updated
cosmetologist_md_exact_matches = {
    r"(?i)\bCosmotologist\s?MD\b",
    r"(?i)\bCosmetoligist\s?MD\b",
    r"(?i)\bCosmetologist\s?M\.?D\.?\b",
    r"(?i)\bCosmatologist\s?MD\b",
    r"(?i)\bMD\s?Cosmotologist\b",
    r"(?i)\bCosmetólogo\s?MD\b",
    r"(?i)\bMédico\s?Cosmetólogo\b",
    r"(?i)\bDoctor\s?en\s?Cosmetología\b",
    r"(?i)\bCosmotologist\b",
    r"(?i)\bCosmetoligist\b",
    r"(?i)\bCosmatologist\b",
    r"(?i)\bCosmetólogo\b",
    r"(?i)\bEspecialista\s?en\s?Cosmetología\b",
    r"(?i)\bCosmetology\b",
    r"(?i)\bCosmetic Medicine\b",
    'Kosmetolog',
    'Medical Micropigmentologist',
}

# Define patterns (these should NOT be changed)
cosmetologist_md_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Cosmetology Nurse',
    'Cosmetologist Student Of Medical Faculty',
    'Cosmetologist & Studing Nurse',
    'Cosmetologist & Esthetician',
    'Beautician Cosmetologist',
    'Cosmetologist Esthetician',
    'Cosmetology Instructor',
    'Cosmetology Teacher',
    'Instructor Of Cosmetology',
    'Supervisor Theatrical Cosmetology',
    'Vocational Instructor Of Cosmetology',
    'Cosmetology Educator',
    'Teacher Cosmetology',
    'Hairdressing & Cosmetology Teacher',
    'Ems& Cosmetology Licensing Aide Professional',
    'High School Cosmetology Instructor',
    'Cosmetology Career Technology Instructor',
    'Division Manager Licensing For The Mn Board Of Cosmetology',
}

# Create a mask for cosmetologist_md
mask_cosmetologist_md = df['speciality'].str.contains('|'.join(cosmetologist_md_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(cosmetologist_md_exact_matches)
mask_cosmetologist_md_exclusions = df['speciality'].isin(cosmetologist_md_exclusions)

# Final mask: Select cosmetologist_md
mask_cosmetologist_md_final = mask_cosmetologist_md & ~mask_cosmetologist_md_exclusions

# Store the original values that will be replaced
original_cosmetologist_md_values = df.loc[mask_cosmetologist_md_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_cosmetologist_md_final, 'speciality'] = 'Cosmetologist MD'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Cosmetologist MD", 'green'))
print(df.loc[mask_cosmetologist_md_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_cosmetologist_md_values = df.loc[mask_cosmetologist_md_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Cosmetologist MD", "cyan"))
for original_cosmetologist_md_value in original_cosmetologist_md_values:
    print(f"✅ {original_cosmetologist_md_value} → Cosmetologist MD")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Cosmetologist MD:", 'red'))
print(grouped_cosmetologist_md_values)

# Print summary
matched_count_cosmetologist_md = mask_cosmetologist_md_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Cosmetologist MD: "
        f"{matched_count_cosmetologist_md}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Psychotherapist related titles

psychotherapist_variants = [
    # Standard Titles & Variants
    r"(?i)\bPsychotherapist\b",
    r"(?i)\bLicensed Psychotherapist\b",
    r"(?i)\bMental Health Therapist\b",
    r"(?i)\bCounselor\b",
    r"(?i)\bClinical Psychotherapist\b",
    r"(?i)\bPsychapist\b",

    # Misspellings & Typographical Errors
    r"(?i)\bPsychotherpist\b",
    r"(?i)\bPsychotherpistt\b",
    r"(?i)\bPsycotherapist\b",
    r"(?i)\bPsychotheripist\b",
    r"(?i)\bPsychotherist\b",
    r"(?i)\bPsychotheraist\b",
    r"(?i)\bPsycotherapist\b",

    # Case Variations
    r"(?i)\bPSYCHOTHERAPIST\b",
    r"(?i)\bpsychotherapist\b",
    r"(?i)\bPyScHoThErApIsT\b",

    # Spanish Variants
    r"(?i)\bPsicoterapeuta\b",
    r"(?i)\bPsicoterapeuta Clínico\b",
    r"(?i)\bPsicoterapeuta Licenciado\b",
    r"(?i)\bConsejero\b",
    r"(?i)\bPsicoterapeuta de la Salud Mental\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bPsicotherapist\b",
    r"(?i)\bPsycotherapist\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bMental Health Counselor\b",
    r"(?i)\bMarriage and Family Therapist\b",
    r"(?i)\bCounseling Psychotherapist\b",
    r"(?i)\bClinical Therapist\b",
    r"(?i)\bPsychiatric Therapist\b",
    r"(?i)\bLicensed Clinical Social Worker\b",
]

# Exact matches that should be updated
psychotherapist_exact_matches = {
    "Psychotherapist",
    "Licensed Psychotherapist",
    "Mental Health Therapist",
    "Counselor",
    "Clinical Psychotherapist",
    "Psychotherpist",
    "Psychotherpistt",
    "Psycotherapist",
    "Psychotheripist",
    "Psychotherist",
    "Psychotheraist",
    "Psicoterapeuta",
    "Terapeuta",
    "Psicoterapeuta Clínico",
    "Psicoterapeuta Licenciado",
    "Consejero",
    "Psicoterapeuta de la Salud Mental",
    "Psicotherapist",
    "Mental Health Counselor",
    "Marriage and Family Therapist",
    "Counseling Psychotherapist",
    "Clinical Therapist",
    "Psychiatric Therapist",
    "Licensed Clinical Social Worker",
}

# # Define patterns (these should NOT be changed)
# psychotherapist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

psychotherapist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Psychotherapist
mask_psychotherapist = df['speciality'].str.contains('|'.join(psychotherapist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(psychotherapist_exact_matches)

# mask_psychotherapist_exclusions = df['speciality'].str.contains(psychotherapist_exclusions, case=False, na=False, regex=True)
mask_psychotherapist_exclusions = df['speciality'].isin(psychotherapist_exclusions)

# Final mask: Select Psychotherapist
mask_psychotherapist_final = mask_psychotherapist & ~mask_psychotherapist_exclusions

# Store the original values that will be replaced
original_psychotherapist_values = df.loc[mask_psychotherapist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_psychotherapist_final, 'speciality'] = 'Psychotherapist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Psychotherapist", 'green'))
print(df.loc[mask_psychotherapist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_psychotherapist_values = df.loc[mask_psychotherapist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Psychotherapist", "cyan"))
for original_psychotherapist_value in original_psychotherapist_values:
    print(f"✅ {original_psychotherapist_value} → Psychotherapist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Psychotherapist:", 'red'))
print(grouped_psychotherapist_values)

# Print summary
matched_count_psychotherapist = mask_psychotherapist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Psychotherapist: "
        f"{matched_count_psychotherapist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Hair Transplant Surgeon related titles

hair_transplant_variants = [
    r"(?i)\bHair\s?Transplant\s?Surgeon\b",
    r"(?i)\bHair\s?Transplant\b",
    r"(?i)\bHair Transplant\b",
    r"(?i)\bHair Surgery\b",
    r"(?i)\bHair Restoration\b",
    r"(?i)\bCirujana Capilar\b",

    # Common misspellings and case errors
    r"(?i)\bHair\s?Transplante\s?Surgeon\b",
    r"(?i)\bHair\s?Transplant\s?Surgen\b",
    r"(?i)\bHair\s?Transplant\s?Surgon\b",
    r"(?i)\bHair\s?Transplant\s?Surgeon\b",

    # Spanish variants
    r"(?i)\bCirujano\s?de\s?Trasplante\s?Capilar\b",
    r"(?i)\bCirujano\s?de\s?Implante\s?Capilar\b",

    # Other possible variations
    r"(?i)\bDoctor\s?Hair\s?Transplant\s?Surgeon\b",
    r"(?i)\bBoard-Certified\s?Hair\s?Transplant\s?Surgeon\b",
    r"(?i)\bHair\s?Restoration\s?Surgeon\b",
    r"(?i)\bHair\s?Transplant\s?Specialist\b",
]

# Exact matches that should be updated
hair_transplant_exact_matches = {
    "Hair Transplant Surgeon",
    "Hair Transplante Surgeon",
    "Hair Transplant Surgen",
    "Hair Transplant Surgon",
    "Cirujano de Trasplante Capilar",
    "Cirujano de Implante Capilar",
    # Other possible variations
    "Doctor Hair Transplant Surgeon",
    "Board-Certified Hair Transplant Surgeon",
    "Hair Restoration Surgeon",
    "Hair Transplant Specialist",
    'Greviste Manifestant',
}

# Define patterns (these should NOT be changed)
hair_transplant_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Hair Transplant Surgeon
mask_hair_transplant = df['speciality'].str.contains('|'.join(hair_transplant_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(hair_transplant_exact_matches)
mask_hair_transplant_exclusions = df['speciality'].isin(hair_transplant_exclusions)

# Final mask: Select Hair Transplant Surgeon
mask_hair_transplant_final = mask_hair_transplant & ~mask_hair_transplant_exclusions

# Store the original values that will be replaced
original_hair_transplant_values = df.loc[mask_hair_transplant_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_hair_transplant_final, 'speciality'] = 'Hair Transplant Surgeon'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Hair Transplant Surgeon", 'green'))
print(df.loc[mask_hair_transplant_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_hair_transplant_values = df.loc[mask_hair_transplant_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Hair Transplant Surgeon", "cyan"))
for original_hair_transplant_value in original_hair_transplant_values:
    print(f"✅ {original_hair_transplant_value} → Hair Transplant Surgeon")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Hair Transplant Surgeon:", 'red'))
print(grouped_hair_transplant_values)

# Print summary
matched_count_hair_transplant = mask_hair_transplant_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Hair Transplant Surgeon: "
        f"{matched_count_hair_transplant}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Rheumatologist related titles

rheumatologist_variants = [
    # Standard Titles & Variants
    r"(?i)\bRheumatologist\b",
    r"(?i)\bRheumatology Specialist\b",
    r"(?i)\bRheumatology Consultant\b",
    r"(?i)\bRheumatic Disease Specialist\b",
    r"(?i)\bRheumatology Physician\b",
    r"(?i)\bRheumatology Doctor\b",

    # Misspellings & Typographical Errors
    r"(?i)\bRheumatoligist\b",
    r"(?i)\bRheumatologistt\b",
    r"(?i)\bRheumatoligistt\b",
    r"(?i)\bReumatologist\b",
    r"(?i)\bRheumatoligst\b",
    r"(?i)\bRheumatogist\b",

    # Case Variations
    r"(?i)\bRHEUMATOLOGIST\b",
    r"(?i)\bRheumatologist\b",
    r"(?i)\bRHEUMATOLOGISTt\b",
    r"(?i)\brheumatologist\b",

    # Spanish Variants
    r"(?i)\bReumatólogo\b",
    r"(?i)\bEspecialista en Reumatología\b",
    r"(?i)\bMédico Reumatólogo\b",
    r"(?i)\bMédico Especialista en Reumatología\b",
    r"(?i)\bEspecialista en Enfermedades Reumáticas\b",
    r"(?i)\bReumatólogo Clínico\b",
    r"(?i)\bReumatología\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bRheumatologist Especialista\b",
    r"(?i)\bRheumatology Reumatólogo\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bRheumatology Specialist\b",
    r"(?i)\bRheumatic Disease Doctor\b",
    r"(?i)\bRheumatology Physician\b",
    r"(?i)\bRheumatology Consultant\b",
    r"(?i)\bReumatic Disease Consultant\b",
    r"(?i)\bArthritis Specialist\b",
    r"(?i)\bChronic Pain Specialist\b",
]

# Exact matches that should be updated
rheumatologist_exact_matches = {
    "Rheumatologist",
    "Rheumatology Specialist",
    "Rheumatology Consultant",
    "Rheumatic Disease Specialist",
    "Rheumatology Physician",
    "Rheumatology Doctor",
    "Rheumatoligist",
    "Rheumatologistt",
    "Rheumatoligistt",
    "Reumatologist",
    "Rheumatoligst",
    "Rheumatogist",
    "RHEUMATOLOGIST",
    "RHEUMATOLOGISTt",
    "rheumatologist",
    "Reumatólogo",
    "Especialista en Reumatología",
    "Médico Reumatólogo",
    "Médico Especialista en Reumatología",
    "Especialista en Enfermedades Reumáticas",
    "Reumatólogo Clínico",
    "Reumatología",
    "Rheumatologist Especialista",
    "Rheumatology Reumatólogo",
    "Rheumatic Disease Doctor",
    "Reumatic Disease Consultant",
    "Arthritis Specialist",
    "Chronic Pain Specialist",
    'RHEUMATOLOGY',
}

# # Define patterns (these should NOT be changed)
# rheumatologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

rheumatologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Rheumatologist
mask_rheumatologist = df['speciality'].str.contains('|'.join(rheumatologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(rheumatologist_exact_matches)

# mask_rheumatologist_exclusions = df['speciality'].str.contains(rheumatologist_exclusions, case=False, na=False, regex=True)
mask_rheumatologist_exclusions = df['speciality'].isin(rheumatologist_exclusions)

# Final mask: Select Rheumatologist
mask_rheumatologist_final = mask_rheumatologist & ~mask_rheumatologist_exclusions

# Store the original values that will be replaced
original_rheumatologist_values = df.loc[mask_rheumatologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_rheumatologist_final, 'speciality'] = 'Rheumatologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Rheumatologist", 'green'))
print(df.loc[mask_rheumatologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_rheumatologist_values = df.loc[mask_rheumatologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Rheumatologist", "cyan"))
for original_rheumatologist_value in original_rheumatologist_values:
    print(f"✅ {original_rheumatologist_value} → Rheumatologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Rheumatologist:", 'red'))
print(grouped_rheumatologist_values)

# Print summary
matched_count_rheumatologist = mask_rheumatologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Rheumatologist: "
        f"{matched_count_rheumatologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Orthodontist related titles

orthodontist_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bOrthodontist\b",
    r"(?i)\bOrtho\b",
    r"(?i)\bOrthodontic\s?Specialist\b",
    r"(?i)\bDoctor\s?of\s?Orthodontics\b",
    r"(?i)\bDDS\s?Orthodontics\b",
    r"(?i)\bDMD\s?Orthodontics\b",

    # Misspellings & Typographical Errors
    r"(?i)\bOrthodentist\b",
    r"(?i)\bOrthodonist\b",
    r"(?i)\bOrthodantist\b",
    r"(?i)\bOrhtodontist\b",
    r"(?i)\bOrthodentics\b",
    r"(?i)\bOrthodentis\b",
    r"(?i)\bOrthodontics\s?Doctor\b",

    # Case Variations
    r"(?i)\borthodontist\b",
    r"(?i)\bOrthodontIst\b",
    r"(?i)\bORTHODONTIST\b",
    r"(?i)\bOrThOdOnTiSt\b",

    # Spanish Variants
    r"(?i)\bOrtodoncista\b",
    r"(?i)\bDoctor\s?en\s?Ortodoncía\b",
    r"(?i)\bEspecialista\s?en\s?Ortodoncía\b",
    r"(?i)\bCirujano\s?Ortodoncista\b",

    # Other Possible Variations (Including Doctor forms, Specialist forms)
    r"(?i)\bOrthodontic\s?Doctor\b",
    r"(?i)\bOrthodontic\s?Surgeon\b",
    r"(?i)\bOrthodontic\s?Practitioner\b",
    r"(?i)\bSpecialist\s?in\s?Orthodontics\b",
    r"(?i)\bOrthodontics\s?Expert\b",
]

# Exact matches that should be updated
orthodontist_exact_matches = {
    "Orthodontist",
    "Ortho",
    "Orthodontic Specialist",
    "Doctor of Orthodontics",
    "DDS Orthodontics",
    "DMD Orthodontics",
    "Orthodentist",
    "Orthodonist",
    "Orthodantist",
    "Orhtodontist",
    "Orthodentics",
    "Orthodentis",
    "Orthodontics Doctor",
    "Ortodoncista",
    "Doctor en Ortodoncia",
    "Especialista en Ortodoncia",
    "Cirujano Ortodoncista",
    "Orthodontic Doctor",
    "Orthodontic Surgeon",
    "Orthodontic Practitioner",
    "Specialist in Orthodontics",
    "Orthodontics Expert",
    'Other Dentistry Specialty',
}

# # Define patterns (these should NOT be changed)
# orthodontist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

orthodontist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Orthodontist
mask_orthodontist = df['speciality'].str.contains('|'.join(orthodontist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(orthodontist_exact_matches)

# mask_orthodontist_exclusions = df['speciality'].str.contains(orthodontist_exclusions, case=False, na=False, regex=True)
mask_orthodontist_exclusions = df['speciality'].isin(orthodontist_exclusions)

# Final mask: Select Orthodontist
mask_orthodontist_final = mask_orthodontist & ~mask_orthodontist_exclusions

# Store the original values that will be replaced
original_orthodontist_values = df.loc[mask_orthodontist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_orthodontist_final, 'speciality'] = 'Orthodontist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Orthodontist", 'green'))
print(df.loc[mask_orthodontist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_orthodontist_values = df.loc[mask_orthodontist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Orthodontist", "cyan"))
for original_orthodontist_value in original_orthodontist_values:
    print(f"✅ {original_orthodontist_value} → Orthodontist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Orthodontist:", 'red'))
print(grouped_orthodontist_values)

# Print summary
matched_count_orthodontist = mask_orthodontist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Orthodontist: "
        f"{matched_count_orthodontist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Dermatologic Surgeon related titles

dermatologic_surgeon_variants = [
    r"(?i)\bdermatologic\s?surgeon\b",
    r"(?i)\bdermatolog\s?surgeon\b",
    r"(?i)\bdermatologic\s?surgon\b",
    r"(?i)\bdermatolgist\s?surgeon\b",
    r"(?i)\bdermatolog\s?surgeon\b",
    r"(?i)\bsurgeon\s?dermatologico\b",
    r"(?i)\bcirujano\s?dermatologico\b",
    r"(?i)\bcirujano\s?dermatologo\b",
    r"(?i)\bdoctor\s?dermatologic\s?surgeon\b",
    r"(?i)\bdermatologic\s?surgical\s?specialist\b",
    r"(?i)\bboard\s?certified\s?dermatologic\s?surgeon\b",
    r"(?i)\bDermatologic Surgery\b",
    r"(?i)\bDermatological Surgery\b",
    r"(?i)\bDermatologistDermatopathologistDermatologic Surgeon\b",
    r"(?i)\bDermatology & Aesthetic Surgery\b",
    r"(?i)\bCirujana Dermatologa\b",
]

# Exact matches that should be updated
dermatologic_surgeon_exact_matches = {
    "Dermatologic Surgeon",
    "Dermatology Surgeon",
    "Dermatologist Surgeon",
    "Dermatologic Surgeons",
    "Dermatologic Surgoen",
    "Dermatoligic Surgeon",
    "Dermatologic Surgion",
    "DERMATOLOGIC SURGEON",
    "dermatologic surgeon",
    "Dr. Dermatologic Surgeon",
    "Board-Certified Dermatologic Surgeon",
    "Board Certified Dermatologic Surgeon",
    "Cirujano Dermatológico",
    "Cirujano Dermatologista",
    "Cirujano dermatológico",
    "Dr. Cirujano Dermatológico",
    "Dr. [Board-Certified Dermatologic Surgeon]",
    'Clinical Dermatology & Aesthetics',
    'CiruDerm',
}

# Define patterns (these should NOT be changed)
dermatologic_surgeon_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident'
}

# Create a mask for Dermatologic Surgeon
mask_dermatologic_surgeon = df['speciality'].str.contains('|'.join(dermatologic_surgeon_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(dermatologic_surgeon_exact_matches)
mask_dermatologic_surgeon_exclusions = df['speciality'].isin(dermatologic_surgeon_exclusions)

# Final mask: Select Dermatologic Surgeon
mask_dermatologic_surgeon_final = mask_dermatologic_surgeon & ~mask_dermatologic_surgeon_exclusions

# Store the original values that will be replaced
original_dermatologic_surgeon_values = df.loc[mask_dermatologic_surgeon_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_dermatologic_surgeon_final, 'speciality'] = 'Dermatologic Surgeon'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Dermatologic Surgeon", 'green'))
print(df.loc[mask_dermatologic_surgeon_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_dermatologic_surgeon_values = df.loc[mask_dermatologic_surgeon_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Dermatologic Surgeon", "cyan"))
for original_dermatologic_surgeon_value in original_dermatologic_surgeon_values:
    print(f"✅ {original_dermatologic_surgeon_value} → Dermatologic Surgeon")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Dermatologic Surgeon:", 'red'))
print(grouped_dermatologic_surgeon_values)

# Print summary
matched_count_dermatologic_surgeon = mask_dermatologic_surgeon_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Dermatologic Surgeon: "
        f"{matched_count_dermatologic_surgeon}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Press related titles

press_variants = [
    # Standard Titles & Variants
    r"(?i)\bPress\b",
    r"(?i)\bMedia\b",
    r"(?i)\bPublic Relations\b",
    r"(?i)\bPR\b",
    r"(?i)\bJournalist\b",

    # Misspellings & Typographical Errors
    r"(?i)\bPess\b",
    r"(?i)\bPrees\b",
    r"(?i)\bPrss\b",
    r"(?i)\bPresss\b",

    # Case Variations
    r"(?i)\bpress\b",
    r"(?i)\bPRESS\b",
    r"(?i)\bPrEsS\b",

    # Spanish Variants
    r"(?i)\bPrensa\b",
    r"(?i)\bRelaciones Públicas\b",
    r"(?i)\bComunicados de Prensa\b",
    r"(?i)\bMedios de Comunicación\b",
    r"(?i)\bDepartamento de Prensa\b",

    # Other Possible Variations
    r"(?i)\bPublic Relations Manager\b",
    r"(?i)\bMedia Relations\b",
    r"(?i)\bMedia Relations Specialist\b",
    r"(?i)\bPress Officer\b",
    r"(?i)\bCommunications\b",
    r"(?i)\bDirectrice De La Rdaction\b",
    r"(?i)\bAssistant Camera Operator\b",
    r"(?i)\bVideo Ad\b",
    r"(?i)\bEditor\b",
    r"(?i)\bFeatures Editor\b",
    r"(?i)\bGiornalista\b",
    r"(?i)\bAuthor\b",
    r"(?i)\bJournaliste\b",
    r"(?i)\bTv Production\b",
]

# Exact matches that should be updated
press_exact_matches = {
    "Press",
    "Media",
    "Public Relations",
    "PR",
    "Pess",
    "Prees",
    "Prss",
    "Presss",
    "Prensa",
    "Relaciones Públicas",
    "Comunicados de Prensa",
    "Medios de Comunicación",
    "Departamento de Prensa",
    "Public Relations Manager",
    "PR Specialist",
    "Media Relations",
    "Media Relations Specialist",
    "Press Officer",
    "PressMedia",
    "PressMedia",
    'Communications',
}

# # Define patterns (these should NOT be changed)
press_exclusions = r'\b(?:Social Media)|(?:Marketing)\b'

# press_exclusions = {
#     'Resident', 'resident', 'student', 'Trainee', 'Resident Doctor', 'Resident ooPhysician',
#     'Intern', 'intern', 'Medical Intern', 'Fellow', 'fellow', 'Clinical Fellow', 'Medical Student',
#     'Clinical Trainee', 'Trainee Doctor', 'Trainee Physician', 'Junior Doctor', 'Postgraduate Trainee',
#     'Aesthetic Fellow', 'Aesthetic Trainee', 'Aesthetic Medicine Fellow', 'Aesthetic Resident'
# }

# Create a mask for Press
mask_press = df['speciality'].str.contains('|'.join(press_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(press_exact_matches)

mask_press_exclusions = df['speciality'].str.contains(press_exclusions, case=False, na=False, regex=True)
# mask_press_exclusions = df['speciality'].isin(press_exclusions)

# Final mask: Select Press
mask_press_final = mask_press & ~mask_press_exclusions

# Store the original values that will be replaced
original_press_values = df.loc[mask_press_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_press_final, 'speciality'] = 'Press'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Press", 'green'))
print(df.loc[mask_press_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_press_values = df.loc[mask_press_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Press", "cyan"))
for original_press_value in original_press_values:
    print(f"✅ {original_press_value} → Press")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Press:", 'red'))
print(grouped_press_values)

# Print summary
matched_count_press = mask_press_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Press: "
        f"{matched_count_press}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Urologist related titles

urologist_variants = [
    # Standard Titles & Variants
    r"(?i)\bUrologist\b",  # General term for Urologist
    r"(?i)\bUrology Specialist\b",  # Alternative term for urologist
    r"(?i)\bUrinary Tract Specialist\b",  # Specific to urinary tract care
    r"(?i)\bKidney Specialist\b",  # Common term for urologist specializing in kidneys
    r"(?i)\bBladder Specialist\b",  # Specialist focused on bladder
    r"(?i)\bMale Reproductive Health Specialist\b",  # Urologists focusing on male reproductive health

    # Misspellings & Typographical Errors
    r"(?i)\bUrolgist\b",  # Common misspelling
    r"(?i)\bUrolgist\b",  # Typo with missing 'o'
    r"(?i)\bUroligist\b",  # Typo with extra 'i'
    r"(?i)\bUrolgists\b",  # Plural form with typo
    r"(?i)\bUroloist\b",  # Typo swapping 'g' and 'i'

    # Case Variations
    r"(?i)\bUROLOGIST\b",  # Uppercase variant
    r"(?i)\burologist\b",  # Lowercase variant
    r"(?i)\bUroLoGiSt\b",  # Mixed case variant

    # Spanish Variants
    r"(?i)\bUrólogo\b",  # General term for Urologist in Spanish
    r"(?i)\bEspecialista en Urología\b",  # Urology Specialist in Spanish
    r"(?i)\bEspecialista en Tracto Urinario\b",  # Urinary Tract Specialist in Spanish
    r"(?i)\bEspecialista en Riñón\b",  # Kidney Specialist in Spanish
    r"(?i)\bEspecialista en Vejiga\b",  # Bladder Specialist in Spanish
    r"(?i)\bEspecialista en Salud Reproductiva Masculina\b",  # Male Reproductive Health Specialist in Spanish

    # Hybrid Spanish-English Variants
    r"(?i)\bUrologist Especialista en Urología\b",  # Hybrid term
    r"(?i)\bUrólogo Kidney Specialist\b",  # Hybrid term

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bUrinary Care Physician\b",  # Medical variant for urologist
    r"(?i)\bReproductive Health Doctor\b",  # Specialist for reproductive health
    r"(?i)\bBladder Surgeon\b",  # Surgeons focusing on bladder treatment
    r"(?i)\bKidney Care Doctor\b",  # Variant focused on kidney care
    r"(?i)\bConsultant Urological Surgeon\b",
    r"(?i)\bUrology\b",
]

# Exact matches that should be updated
urologist_exact_matches = {
    "Urologist",
    "Urology Specialist",
    "Urinary Tract Specialist",
    "Kidney Specialist",
    "Bladder Specialist",
    "Male Reproductive Health Specialist",
    "Urolgist",
    "Uroligist",
    "Urolgists",
    "Uroloist",
    "UROLOGIST",
    "urologist",
    "UroLoGiSt",
    "Urólogo",
    "Especialista en Urología",
    "Especialista en Tracto Urinario",
    "Especialista en Riñón",
    "Especialista en Vejiga",
    "Especialista en Salud Reproductiva Masculina",
    "Urologist Especialista en Urología",
    "Urólogo Kidney Specialist",
    "Urinary Care Physician",
    "Reproductive Health Doctor",
    "Bladder Surgeon",
    "Kidney Care Doctor",
}

# # Define patterns (these should NOT be changed)
# urologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

urologist_exclusions = {
    'Resident', 'resident', 'student', 'Trainee', 'Resident Doctor', 'Resident ooPhysician',
    'Intern', 'intern', 'Medical Intern', 'Fellow', 'fellow', 'Clinical Fellow', 'Medical Student',
    'Clinical Trainee', 'Trainee Doctor', 'Trainee Physician', 'Junior Doctor', 'Postgraduate Trainee',
    'Aesthetic Fellow', 'Aesthetic Trainee', 'Aesthetic Medicine Fellow', 'Aesthetic Resident'
}

# Create a mask for Urologist
mask_urologist = df['speciality'].str.contains('|'.join(urologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(urologist_exact_matches)

# mask_urologist_exclusions = df['speciality'].str.contains(urologist_exclusions, case=False, na=False, regex=True)
mask_urologist_exclusions = df['speciality'].isin(urologist_exclusions)

# Final mask: Select Urologist
mask_urologist_final = mask_urologist & ~mask_urologist_exclusions

# Store the original values that will be replaced
original_urologist_values = df.loc[mask_urologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_urologist_final, 'speciality'] = 'Urologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Urologist", 'green'))
print(df.loc[mask_urologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_urologist_values = df.loc[mask_urologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Urologist", "cyan"))
for original_urologist_value in original_urologist_values:
    print(f"✅ {original_urologist_value} → Urologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Urologist:", 'red'))
print(grouped_urologist_values)

# Print summary
matched_count_urologist = mask_urologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Urologist: "
        f"{matched_count_urologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Immunologist related titles

immunologist_variants = [
    r"(?i)\bImmunologist\b",

    # Common misspellings and case errors
    r"(?i)\bImunologist\b",
    r"(?i)\bImmnuologist\b",
    r"(?i)\bImmunoligist\b",
    r"(?i)\bImmunollogist\b",
    r"(?i)\bImmunolgist\b",
    r"(?i)\bVirologist\b",

    # Spanish variants
    r"(?i)\bInmunólogo\b",
    r"(?i)\bInmunóloga\b",
    r"(?i)\bEspecialista\s?en\s?Inmunología\b",

    # Other possible variations
    r"(?i)\bImmunology\s?Specialist\b",
    r"(?i)\bDoctor\s?of\s?Immunology\b",
    r"(?i)\bClinical\s?Immunologist\b",
    r"(?i)\bResearch\s?Immunologist\b",
    r"(?i)\bAllergy\s?and\s?Immunology\s?Specialist\b",
    r"(?i)\bImmunology\b",
    r"(?i)\bAllergy Immunology\b",
    r"(?i)\bAllergy\b",
]

# Exact matches that should be updated
immunologist_exact_matches = {
    "Immunologist",
    "Imunologist",
    "Immnuologist",
    "Immunoligist",
    "Immunollogist",
    "Immunolgist",
    # Spanish variants
    "Inmunólogo",
    "Inmunóloga",
    "Especialista en Inmunología",
    # Other possible variations
    "Immunology Specialist",
    "Doctor of Immunology",
    "Clinical Immunologist",
    "Research Immunologist",
    "Allergy and Immunology Specialist",
}

# Define patterns (these should NOT be changed)
immunologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Field Director- Immunology & Dermatology',
    'Senior Sales Immunology- Dermatology',
    'District Western Pa Immunology Dermatology Franchise Senior District Sales Manager',
    'Medical Science Executive & Dermatology Immunology Liaison',
    'Immunology Specialty Sales-Dermatology',
    'Immunology Sales Janssen Biotech Inc Dermatology At Johnson & Johnson Specialist',
    'Thought Leader Liaison Strategic Marketing Immunology Dermatology',
    'Sales Executive & Immunology Dermatology Specialist',
    'Immunology Sales Dermatology Specialist',
    'Immunology Sales -Dermatology Specialist',
}

# Create a mask for Immunologist
mask_immunologist = df['speciality'].str.contains('|'.join(immunologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(immunologist_exact_matches)
mask_immunologist_exclusions = df['speciality'].isin(immunologist_exclusions)

# Final mask: Select Immunologist
mask_immunologist_final = mask_immunologist & ~mask_immunologist_exclusions

# Store the original values that will be replaced
original_immunologist_values = df.loc[mask_immunologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_immunologist_final, 'speciality'] = 'Immunologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Immunologist", 'green'))
print(df.loc[mask_immunologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_immunologist_values = df.loc[mask_immunologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Immunologist", "cyan"))
for original_immunologist_value in original_immunologist_values:
    print(f"✅ {original_immunologist_value} → Immunologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Immunologist:", 'red'))
print(grouped_immunologist_values)

# Print summary
matched_count_immunologist = mask_immunologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Immunologist: "
        f"{matched_count_immunologist}",
        'red'))


import pandas as pd
import numpy as np
import re
from nltk.corpus import stopwords
import unicodedata
import sys
import os
from termcolor import colored

# Remove the original_speciality column as no longer needed
df = df.drop(columns = ['original_speciality'])

# Declare the list of values available in main_title table
list_of_job_titles = [
    'Acupuncturist',
    'Advanced Registered Nurse Practitioner (ARNP)',
    'Aesthetic & Anti-aging Physician',
    'Aesthetic & Plastic Surgeon',
    'Aesthetic Physician',
    'Alternative Medicine Physician',
    'Anaesthesist',
    'Anatomist',
    'Andrologist',
    'Angiologist Phlebologist',
    'Anti-aging Physician',
    'Biologist Biochemist',
    'Biomedical Physician',
    'Cardiologist',
    'Clinic Manager',
    'Clinical Staff',
    'Company CEO',
    'Company Manager',
    'Company Medical Staff',
    'Company Representative',
    'Consultant',
    'Cosmetic Dermatologist',
    'Cosmetic Surgeon',
    'Cosmetologist MD',
    'Cytologist',
    'Dental Assistant',
    'Dental Surgeon',
    'Dentist',
    'Dermatologic Surgeon',
    'Dermatologist',
    'Distributor',
    'Employee',
    'Endocrinologist',
    'ENT Ear Nose Throat Physician',
    'Esthetician Cosmetician',
    'Event Manager',
    'Facial Plastic Surgeon',
    'General Physician',
    'General Surgeon',
    'Genetician',
    'Geriatrist',
    'Gynecologist Obstetrician',
    'Hair Transplant Surgeon',
    'Head of department',
    'Hematologist',
    'Hospital Manager',
    'Immunologist',
    'Influencer',
    'Internal Medicine',
    'Laboratory Medicine',
    'Lawyer',
    'Legal Counsel',
    'Licensed Practical Nurse (LPN)',
    'Marketing Manager',
    'Maxillofacial Surgeon',
    'Medical Advisor',
    'Medical Spa Manager',
    'Neonatologist',
    'Neurologist',
    'Neurophysiologist',
    'Non medical Staff',
    'Nurse Practitioner (NP)',
    'Nutritionist',
    'Oculoplastic Surgeon',
    'Oncologist',
    'Ophthalmologist',
    'Oral and Maxillofacial Surgeon',
    'Orthodontist',
    'Orthopedist',
    'Owner',
    'Pathologist',
    'Pediatrician',
    'Pharmacist',
    'Pharmacologist',
    'Photographer',
    'Physician Assistant',
    'Physiotherapist',
    'Plastic and Reconstructive Surgeon',
    'Plastic Surgeon',
    'Practice Manager',
    'Press',
    'Product Project Manager',
    'Professor Teacher',
    'Psychiatrist',
    'Psychologist',
    'Psychotherapist',
    'Radiologist',
    'Registered Nurse (RN)',
    'Research Scientist',
    'Rheumatologist',
    'Sales',
    'Sports Medicine Physician',
    'Stomatologist',
    'Student Resident Fellow',
    'Trichologist',
    'Urologist',
    'Vascular Surgeon',
    'ENT Head and Neck Specialist', # FOR EUROGIN
	'General Manager', # Old Value and doesnt exists in main title
	'Nurse' # Old Value and doesnt exists in main title
]

# Filter non-matching job titles after processing
not_transformed_job_titles = pd.DataFrame(df[~df['speciality'].isin(list_of_job_titles)])

# GroupBy to count how many records were not transformed to business format
grouped_not_transformed_job_titles = not_transformed_job_titles['speciality'].value_counts()

# Print non-matching titles and their count
print(colored("\nRemaining Job Titles that have not been transformed to business value format after processing:", 'red'))
print(tab(grouped_not_transformed_job_titles.head(100).reset_index(), headers=['Speciality', 'Count'], tablefmt='psql'))

# Print count of non-matching job titles
print(colored(f"Count of non-matching job titles after processing: {not_transformed_job_titles.shape[0]}", 'red'))

# Filtering logic - Job Title Is Other, Unknown, an integer or not relevant after processing
df_records_job_title_other = not_transformed_job_titles[
    not_transformed_job_titles['speciality'].astype(str).str.strip().isin(['Other', 'Unknown', 'None']) |  # Remove specified values
    not_transformed_job_titles['speciality'].astype(str).str.match(r'^\d+$') |  # Remove numbers only
    not_transformed_job_titles['speciality'].astype(str).str.match(r'^[A-Za-z]$')  # Remove single letters
]

# Print records were Job Title Is Other, Unknown, an integer or not relevant after processing
print(colored("\nJob Title Is Other, Unknown, an integer or not relevant:", 'red'))
print(tab(df_records_job_title_other.head(10).reset_index(),  headers='keys', tablefmt='psql'))

# Print count of records were Job Title Is Other, Unknown, an integer or not relevant after processing
print(colored(f"\nCount Job Title Is Other, Unknown, an integer or not relevant: {df_records_job_title_other.shape[0]}", 'red'))

print(colored("\nRecords were job_title has been transformed:", 'red'))
# Filter only transformed records (those that were successfully replaced)
transformed_job_titles = df[df['speciality'].isin(list_of_job_titles)].copy()
print(tab(transformed_job_titles.head(10), headers='keys', tablefmt='psql'))

# create a copy for concat operation during ML Stages
df_transformed = transformed_job_titles.copy()
print(colored("\nFinal Dataframe at the end of processing Job Titles Pipeline", "red", attrs=["bold"]))
print(tab(df_transformed.head(10), headers='keys', tablefmt='psql'))

# Print count of records with transformed job titles
print(colored(f"\nCount of transformed job titles after Processing: {transformed_job_titles.shape[0]}", 'red'))

# Get the row counts of df_test and df
count_not_transformed_job_titles = len(not_transformed_job_titles)

# For Programmer's Review
if count_not_transformed_job_titles > 0:
    print(colored(
        "\nThe count of not transformed job titles is greater than 0. The programmer needs to review these values "
        "\nbefore proceeding with further execution.", 'red'))

    # Print the count for debugging
    print(f"Count of not transformed job titles: {count_not_transformed_job_titles}")

    # Exit the pipeline
    sys.exit("Exiting pipeline as programmer needs to review the non-transformed job titles.")
else:
    print(colored(
        "\nThe count of transformed job titles is 0. The pipeline proceeds to the next stages.", 'green'))

    # Print the count for confirmation
    print(f"Count of not transformed job titles: {count_not_transformed_job_titles}")

# Concat Frames for next stage of execution
df = pd.concat([
    df,
    not_transformed_job_titles,
    df_other,
    df_CWS
], ignore_index=True)

print(colored("\nFinal Dataframe at the end of processing Job Titles Pipeline that will be sent for further execution", "red", attrs=["bold"]))
print(tab(df_transformed.head(10), headers='keys', tablefmt='psql'))

# Print count of records with transformed job titles
print(colored(f"\nCount of records at the end of processing Job Titles Pipeline that will be sent for further execution: {transformed_job_titles.shape[0]}", 'red'))

# Testing

# Get the row counts of df_test and df
count_df_test = len(df_test)
count_df = len(df)

# Check if the counts match
if count_df_test == count_df:
    print(colored(
        "\nThe count of source dataframe before processing job title transformation stages and after processing job "
        "\ntitle transformation pipeline remains same/equal. Thus, the pipeline will proceed its execution.", 'green'))
else:
    print(colored(
        "\nThe count of source dataframe before processing job title transformation stages and after processing job "
        "\ntitle transformation pipeline are not same/equal. Thus, the pipeline will stop its execution, you need to "
        "\nreview the pipeline.", 'red'))

    # Print the counts
    print(f"Count of df_test: {count_df_test}")
    print(f"Count of df: {count_df}")

    # Exit the program if the counts don't match
    sys.exit("Exiting pipeline due to mismatched record counts.")

# Tip: Uncomment the below if you want to club / pool all the list of variants and exact match DICT into one list and one DICT

# # Initialize lists to hold all variants and exact matches
# all_variants = []
# all_exact_matches = []
#
# # Create a snapshot of all global variables
# global_vars = globals().copy()
#
# # Iterate over the keys in the snapshot of globals
# for var_name, var_value in global_vars.items():
#     if var_name.endswith('_variants'):  # If the variable is a _variants list
#         all_variants.extend(var_value)  # Add the variants to the all_variants list
#     elif var_name.endswith('_exact_matches'):  # If the variable is a _exact_matches set or list
#         if isinstance(var_value, dict):
#             all_exact_matches.extend(var_value.values())  # Add the exact match values to the all_exact_matches list
#         elif isinstance(var_value, (set, list)):  # Check if it's a set or a list
#             all_exact_matches.extend(var_value)  # Use extend to add the elements
#
# # Check the results
# print("All Variants:", all_variants)
# print("All Exact Matches:", all_exact_matches)





import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Cardiologist related titles

cardiologist_variants = [
    r"(?i)\bCardiologist\b",
    r"(?i)\bHeart\s?Specialist\b",
    r"(?i)\bCardiovascular\s?Physician\b",
    r"(?i)\bHeart\s?Doctor\b",
    r"(?i)\bCardiology\s?Specialist\b",
    r"(?i)\bCardiology\s?Physician\b",
    r"(?i)\bDoctor\s?of\s?Cardiology\b",
    r"(?i)\bCardiologist\s?Expert\b",
    r"(?i)\bCardiology\s?Expert\b",
    r"(?i)\bCardiolog\s?Expert\b",
    r"(?i)\bCardiologia Y Estetica\b",
    r"(?i)\bHead Preventive Cardiology\b",
]

# Exact matches that should be updated
cardiologist_exact_matches = {
    'Cardiologist',
    'Heart Specialist',
    'Cardiovascular Physician',
    'Heart Doctor',
    'Cardiology Specialist',
    'Cardiology Physician',
    'Doctor of Cardiology',
    'Cardiologist Expert',
    'Cardiology Expert',

    # Case-related errors
    'cardiologist',
    'heart specialist',
    'cardiovascular physician',
    'heart doctor',
    'cardiology specialist',
    'cardiology physician',
    'doctor of cardiology',
    'cardiologist expert',
    'CARDIOLOGIST',
    'HEART SPECIALIST',
    'CARDIOVASCULAR PHYSICIAN',
    'HEART DOCTOR',
    'CARDIOLOGY SPECIALIST',
    'CARDIOLOGY PHYSICIAN',
    'DOCTOR OF CARDIOLOGY',
    'CARDIOLOGIST EXPERT',

    # Common misspellings
    'Cardioligist',
    'Cardioligist Physician',
    'Cardiologyst',
    'Cardilogist',
    'Cardiologistc',
    'Cardioligyst',
    'Cardiolgist',
    'Cadiologist',
    'Cadiologyst',
    'Cardiologiest',
    'Cardiolgist',

    # Spanish-related exclusions
    'Cardiólogo',
    'Médico Cardiólogo',
    'Especialista en Cardiología',
    'Cardiólogo especialista',
    'Médico de Corazón',
    'Médico Cardiovascular',
    'Especialista en Cardiología Médica',
    'Médico Cardiólogo Experto',
    'Especialista en Enfermedades Cardíacas',
    'Cardiology',
    'CVR',
}

# Define patterns for  & Resident & Professor (these should NOT be changed)
cardiologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Cardiology Physician Assistant',
 }

# Create a mask for Cardiologist
mask_cardiologist = df['speciality'].str.contains('|'.join(cardiologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(cardiologist_exact_matches)
mask_cardiologist_exclusions = df['speciality'].isin(cardiologist_exclusions)

# Final mask: Select Cardiologist
mask_cardiologist_final = mask_cardiologist & ~mask_cardiologist_exclusions

# Store the original values that will be replaced
original_cardiologist_values = df.loc[mask_cardiologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_cardiologist_final, 'speciality'] = 'Cardiologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Cardiologist", 'green'))
print(df.loc[mask_cardiologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_cardiologist_values = df.loc[mask_cardiologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Cardiologist", "cyan"))
for original_cardiologist_value in original_cardiologist_values:
    print(f"✅ {original_cardiologist_value} → Cardiologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Cardiologist:", 'red'))
print(grouped_cardiologist_values)

# Print summary
matched_count_cardiologist = mask_cardiologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Cardiologist: "
        f"{matched_count_cardiologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Genetician related titles

genetician_variants = [
    r"(?i)\bGenetician\b",
    r"(?i)\bGenetician\s?Specialist\b",
    r"(?i)\bBoard\s?Certified\s?Genetician\b",
    r"(?i)\bCertified\s?Genetician\b",

    # Spanish variants
    r"(?i)\bGenetista\b",
    r"(?i)\bEspecialista\s?en\s?Genética\b",
    r"(?i)\bGenetista\s?Médico\b",

    # Other possible variations
    r"(?i)\bDoctor\s?Genetician\b",
    r"(?i)\bDoctor\s?en\s?Genética\b",
    r"(?i)\bGenetics\s?Specialist\b",
    r"(?i)\bGenetics\s?Doctor\b",
    r"(?i)\bGenetic\s?Physician\b",
    r"(?i)\bLicensed\s?Genetician\b",
    r"(?i)\bGeneticista\b",
]

# Exact matches that should be updated
genetician_exact_matches = {
    "Genetician",
    "Genetician Specialist",
    "Board Certified Genetician",
    "Certified Genetician",
    # Spanish form matches
    "Genetista",
    "Especialista en Genética",
    "Genetista Médico",
    # Other possible variations
    "Doctor Genetician",
    "Doctor en Genética",
    "Genetics Specialist",
    "Genetics Doctor",
    "Genetic Physician",
    "Licensed Genetician",
}

# Define patterns (these should NOT be changed)
genetician_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Genetician
mask_genetician = df['speciality'].str.contains('|'.join(genetician_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(genetician_exact_matches)
mask_genetician_exclusions = df['speciality'].isin(genetician_exclusions)

# Final mask: Select Genetician
mask_genetician_final = mask_genetician & ~mask_genetician_exclusions

# Store the original values that will be replaced
original_genetician_values = df.loc[mask_genetician_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_genetician_final, 'speciality'] = 'Genetician'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Genetician", 'green'))
print(df.loc[mask_genetician_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_genetician_values = df.loc[mask_genetician_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Genetician", "cyan"))
for original_genetician_value in original_genetician_values:
    print(f"✅ {original_genetician_value} → Genetician")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Genetician:", 'red'))
print(grouped_genetician_values)

# Print summary
matched_count_genetician = mask_genetician_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Genetician: "
        f"{matched_count_genetician}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Vascular Surgeon related titles

vascular_variants = [
    # Standard Titles & Variants
    r"(?i)\bVascular Surgeon\b",  # General term for Vascular Surgeon
    r"(?i)\bVascular Specialist\b",  # Variant term for vascular specialists
    r"(?i)\bVein Specialist\b",  # Specialist focusing on veins
    r"(?i)\bArterial Specialist\b",  # Specialist focusing on arteries
    r"(?i)\bBlood Vessel Surgeon\b",  # Alternative term for vascular surgeon

    # Misspellings & Typographical Errors
    r"(?i)\bVascualr Surgeon\b",  # Common misspelling
    r"(?i)\bVaskular Surgeon\b",  # Typo swapping letters
    r"(?i)\bVasular Surgeon\b",  # Missing one 'c'
    r"(?i)\bVascular Surgeoon\b",  # Double 'o' mistake
    r"(?i)\bVasculer Surgeon\b",  # Common typo with 'e' instead of 'a'

    # Case Variations
    r"(?i)\bVASCULAR SURGEON\b",  # Uppercase variant
    r"(?i)\bvascular surgeon\b",  # Lowercase variant
    r"(?i)\bVaScUlAr SuRgEoN\b",  # Mixed case variant

    # Spanish Variants
    r"(?i)\bCirujano Vascular\b",  # Vascular Surgeon in Spanish
    r"(?i)\bEspecialista en Vasos Sanguíneos\b",  # Blood Vessel Specialist in Spanish
    r"(?i)\bEspecialista en Venas\b",  # Vein Specialist in Spanish
    r"(?i)\bEspecialista en Arterias\b",  # Arterial Specialist in Spanish
    r"(?i)\bCirujano de Arterias y Venas\b",  # Arteries and Veins Surgeon in Spanish

    # Hybrid Spanish-English Variants
    r"(?i)\bVascular Surgeon Cirujano Vascular\b",  # Hybrid term
    r"(?i)\bVein Specialist Cirujano de Venas\b",  # Hybrid term

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bArterial Surgeon\b",  # Arterial-focused surgeon
    r"(?i)\bVein Surgeon\b",  # Vein-focused surgeon
    r"(?i)\bPeripheral Vascular Surgeon\b",  # Specialist in peripheral vascular surgery
    r"(?i)\bConsultantVascular Surgery\b",
    r"(?i)\bVasc Surgery\b",
    r"(?i)\bMd Vascular Surgery\b",
    r"(?i)\bVascular Consultant\b",
    r"(?i)\bVascular Medicine Specialist\b",
    r"(?i)\bVascular Disease Doctor\b",
    r"(?i)\bEndovascular Specialist\b",
]

# Exact matches that should be updated
vascular_exact_matches = {
    "Vascular Surgeon",
    'Vascular Doctor',
    'Vascular Consultant',
    'Vascular Disease Doctor',
    'Endovascular Specialist',
    "Vascular Specialist",
    "Vein Specialist",
    "Arterial Specialist",
    "Blood Vessel Surgeon",
    "Vascualr Surgeon",
    "Vaskular Surgeon",
    "Vasular Surgeon",
    "Vascular Surgeoon",
    "Vasculer Surgeon",
    "VASCULAR SURGEON",
    "vascular surgeon",
    "VaScUlAr SuRgEoN",
    "Cirujano Vascular",
    "Especialista en Vasos Sanguíneos",
    "Especialista en Venas",
    "Especialista en Arterias",
    "Cirujano de Arterias y Venas",
    "Vascular Surgeon Cirujano Vascular",
    "Vein Specialist Cirujano de Venas",
    "Arterial Surgeon",
    "Vein Surgeon",
    "Peripheral Vascular Surgeon",
    'Vascular Medicine Specialist',
    'Vascular Specialist Doctor',
    'Especialista en Enfermedades Vasculares',
    'Especialista Endovascular',
    'Medecin Vasculaire Et Esthetique',
}

# # Define patterns (these should NOT be changed)
# vascular_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

vascular_exclusions = {
    'Resident', 'resident', 'student', 'Trainee', 'Resident Doctor', 'Resident ooPhysician',
    'Intern', 'intern', 'Medical Intern', 'Fellow', 'fellow', 'Clinical Fellow', 'Medical Student',
    'Clinical Trainee', 'Trainee Doctor', 'Trainee Physician', 'Junior Doctor', 'Postgraduate Trainee',
    'Aesthetic Fellow', 'Aesthetic Trainee', 'Aesthetic Medicine Fellow', 'Aesthetic Resident'
}

# Create a mask for Vascular Surgeon
mask_vascular = df['speciality'].str.contains('|'.join(vascular_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(vascular_exact_matches)

# mask_vascular_exclusions = df['speciality'].str.contains(vascular_exclusions, case=False, na=False, regex=True)
mask_vascular_exclusions = df['speciality'].isin(vascular_exclusions)

# Final mask: Select Vascular Surgeon
mask_vascular_final = mask_vascular & ~mask_vascular_exclusions

# Store the original values that will be replaced
original_vascular_values = df.loc[mask_vascular_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_vascular_final, 'speciality'] = 'Vascular Surgeon'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Vascular Surgeon", 'green'))
print(df.loc[mask_vascular_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_vascular_values = df.loc[mask_vascular_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Vascular Surgeon", "cyan"))
for original_vascular_value in original_vascular_values:
    print(f"✅ {original_vascular_value} → Vascular Surgeon")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Vascular Surgeon:", 'red'))
print(grouped_vascular_values)

# Print summary
matched_count_vascular = mask_vascular_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Vascular Surgeon: "
        f"{matched_count_vascular}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Cytologist related titles

cytologist_variants = [
    # Standard title variations
    r"(?i)\bCytologist\b",
    r"(?i)\bCytology\s?Specialist\b",
    r"(?i)\bCytotechnologist\b",
    r"(?i)\bClinical\s?Cytologist\b",
    r"(?i)\bMedical\s?Cytologist\b",

    # Common misspellings and case mistakes
    r"(?i)\bCyotologist\b",
    r"(?i)\bCytoligist\b",
    r"(?i)\bCytolologist\b",
    r"(?i)\bCytoligyst\b",

    # Variants in Spanish and other languages
    r"(?i)\bCitólogo\b",
    r"(?i)\bEspecialista\s?en\s?Citología\b",
    r"(?i)\bTécnico\s?en\s?Citología\b",

    # Other possible variations
    r"(?i)\bBoard\s?-?\s?Certified\s?Cytologist\b",
    r"(?i)\bPathology\s?Cytologist\b",
    r"(?i)\bDiagnostic\s?Cytologist\b",
]

# Exact matches that should be updated
cytologist_exact_matches = {
    r"(?i)\bCyotologist\b",
    r"(?i)\bCytoligist\b",
    r"(?i)\bCytolologist\b",
    r"(?i)\bCytoligyst\b",
    r"(?i)\bCitólogo\b",
    r"(?i)\bEspecialista\s?en\s?Citología\b",
    r"(?i)\bTécnico\s?en\s?Citología\b",
}

# Define patterns (these should NOT be changed)
cytologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for cytologist
mask_cytologist = df['speciality'].str.contains('|'.join(cytologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(cytologist_exact_matches)
mask_cytologist_exclusions = df['speciality'].isin(cytologist_exclusions)

# Final mask: Select cytologist
mask_cytologist_final = mask_cytologist & ~mask_cytologist_exclusions

# Store the original values that will be replaced
original_cytologist_values = df.loc[mask_cytologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_cytologist_final, 'speciality'] = 'Cytologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Cytologist", 'green'))
print(df.loc[mask_cytologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_cytologist_values = df.loc[mask_cytologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Cytologist", "cyan"))
for original_cytologist_value in original_cytologist_values:
    print(f"✅ {original_cytologist_value} → Cytologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Cytologist:", 'red'))
print(grouped_cytologist_values)

# Print summary
matched_count_cytologist = mask_cytologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Cytologist: "
        f"{matched_count_cytologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored


# Define regex patterns for Non medical Staff related titles

non_medical_staff_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bNon\s?Medical\s?Staff\b",
    r"(?i)\bNon\s?Med\s?Staff\b",
    r"(?i)\bNon\s?Healthcare\s?Staff\b",
    r"(?i)\bNon\s?Clinical\s?Staff\b",
    r"(?i)\bNon\s?Medical\s?Personnel\b",
    r"(?i)\bAdministrative\s?Staff\b",
    r"(?i)\bHospital\s?Administrative\s?Staff\b",
    r"(?i)\bMedical\s?Office\s?Staff\b",
    r"(?i)\bHealthcare\s?Support\s?Staff\b",
    r"(?i)\bExecutive Assistant\b",
    r"(?i)\bMedico Nao Socio\b",
    r"(?i)\bHotel Chain\b",
    r"(?i)\bDecorator\b",
    r"(?i)\bAnalyst\b",
    r"(?i)\bData\b",
    r"(?i)\bAdministrative Assistant\b",
    r"(?i)\bRecruitment Lead\b",
    r"(?i)\bTalent Acquisition Manager\b",
    r"(?i)Talent Acquisition",
    r"(?i)\bOffice Job\b",
    r"(?i)\bMedical Technologist\b",
    r"(?i)\bSecretaire De Direction\b",
    r"(?i)\bInterpreter\b",
    r"(?i)\bOffice Staff\b",
    r"(?i)\bAmministratore Delegato\b",
    r"(?i)\bOffice ManagerBookkeeper\b",
    r"(?i)\bSafety Officer\b",
    r"(?i)\bKitchen Assistance\b",
    r"(?i)\bTecnology\b",
    r"(?i)\bAdmin Assist\b",
    r"(?i)\bOffice Work\b",
    r"(?i)\bProgrammer\b",
    r"(?i)\bAdministrative Manager\b",
    r"(?i)\bNon Specialist\b",
    r"(?i)\bTechnical Department Spare Part Assistant\b",
    r"(?i)\bWorldS First Ai Writing Assistant\b",

    # Misspellings & Typographical Errors
    r"(?i)\bNon\s?Medial\s?Staff\b",
    r"(?i)\bNone\s?Medical\s?Staff\b",
    r"(?i)\bNon\s?Medicl\s?Staff\b",
    r"(?i)\bNon\s?Medicall\s?Staff\b",
    r"(?i)\bNon\s?Medicia\s?Staff\b",
    r"(?i)\bNon\s?Mdical\s?Staff\b",
    r"(?i)\bNon\s?Meducal\s?Staff\b",
    r"(?i)\bNonn\s?Medical\s?Staff\b",
    r"(?i)\bNon\s?Medikal\s?Staff\b",
    r"(?i)\bNon\s?Meddical\s?Staff\b",

    # Case Variations
    r"(?i)\bnon medical staff\b",
    r"(?i)\bNon Medical staff\b",
    r"(?i)\bnon Medical Staff\b",
    r"(?i)\bNON MEDICAL STAFF\b",
    r"(?i)\bNonMed Staff\b",

    # Spanish Variants
    r"(?i)\bPersonal\s?No\s?Médico\b",
    r"(?i)\bEmpleado\s?No\s?Médico\b",
    r"(?i)\bTrabajador\s?No\s?Médico\b",
    r"(?i)\bStaff\s?No\s?Clínico\b",
    r"(?i)\bPersonal\s?Administrativo\s?de\s?Salud\b",

    # Other Possible Variations (Including Doctor/Specialist Forms)
    r"(?i)\bNon\s?Medical\s?Assistant\b",
    r"(?i)\bMedical\s?Receptionist\b",
    r"(?i)\bMedical\s?Secretary\b",
    r"(?i)\bHospital\s?Clerk\b",
    r"(?i)\bHealthcare\s?Administrative\s?Staff\b",
    r"(?i)\bMedical\s?Support\s?Staff\b",
    r"(?i)\bIt\b",
    r"(?i)\bSecretary\b",
    r"(?i)\bAssistant Cook\b",
    r"(?i)\bElectricien\b",
    r"(?i)\bIngeniero De Sistemas\b",
    r"(?i)\bSoftware Engineer\b",
    r"(?i)\bAdministrative Officer\b",
    r"(?i)\bAdministration\b",
    r"(?i)\bControl Officer\b",
    r"(?i)\bEngineering\b",
    r"(?i)\bEnegineer\b",
    r"(?i)\bElectricien\b",
    r"(?i)\bTalent Acquisition Manager\b",
    r"(?i)\bAnalyst\b",
    r"(?i)\bSenior Business Operation Analyst\b",
    r"(?i)\bExecutive Assistant\b",
    r"(?i)\bData\b",
    r"(?i)\bBiomedical Engineer\b",
    r"(?i)\bElectrical Engineer\b",
    r"(?i)\bAircraft Engineer\b",
    r"(?i)\bMedico Nao Socio\b",
    r"(?i)\bIngeniero De Sistemas\b",
    r"(?i)\bAdministration\b",
    r"(?i)\bAdministrative Assistant\b",
    r"(?i)\bAdmin\b",
    r"(?i)\bAdministrative Officer\b",
    r"(?i)\bMedical Technologist\b",
    r"(?i)\bOffice Job\b",
    r"(?i)\bIt Specialist\b",
    r"(?i)\bChemical Engineering\b",
    r"(?i)\bData Entry\b",
    r"(?i)\bEngineering\b",
    r"(?i)\bInformation Technologies It\b",
    r"(?i)\bRisk Analyst\b",
    r"(?i)\bIt\b",
    r"(?i)\bIt Manager\b",
    r"(?i)\bKitchen Assistance\b",
    r"(?i)\bOffice Staff\b",
    r"(?i)\bExecutive Assistant At Skillmed\b",
    r"(?i)\bDirector Of It\b",
    r"(?i)\bIt Services Manager\b",
    r"(?i)\bDecorator\b",
    r"(?i)\bInterpreter\b",
    r"(?i)\bControl Officer\b",
    r"(?i)\bData Entiry\b",
    r"(?i)\bIt Director\b",
    r"(?i)\bApplication Support Analyst\b",
    r"(?i)\bTecnology\b",
    r"(?i)\bJapanese Interpreter\b",
    r"(?i)\bAmministratore Delegato\b",
    r"(?i)\bCredit Control Business Analyst\b",
    r"(?i)\bSenior Business Analyst\b",
    r"(?i)\bMedical Engineer\b",
    r"(?i)\bOffice ManagerBookkeeper\b",
    r"(?i)\bSafety Officer\b",
    r"(?i)\bAvionics Technician\b",
    r"(?i)\bSecretary-General Of The Expert Group\b",
    r"(?i)\bData Interi\b",
    r"(?i)\bResearch Analyst\b",
    r"(?i)\bSecretary Of Society\b",
    r"(?i)\bAdmin Assist\b",
    r"(?i)\bOffice Work\b",
    r"(?i)\bProgrammer\b",
    r"(?i)\bAdministrative Manager\b",
    r"(?i)\bSecretary Ips\b",
    r"(?i)\bBiomedical Enegineer\b",
    r"(?i)\bCustomer Service Engineer\b",
    r"(?i)\bSystem Analyst\b",
    r"(?i)\bRecruitment Lead\b",
    r"(?i)\bHotel Chain\b",
    r"(?i)\bData Services Executive\b",
    r"(?i)\bDeputy Director Of It\b",
    r"(?i)\bData Analyst\b",
    r"(?i)\bNon Specialist\b",
    r"(?i)\bField Application Engineer\b",
    r"(?i)\bGraduate In Administration\b",
    r"(?i)\bPortfolio Analyst\b",
    r"(?i)\bTissue Engineering\b",
    r"(?i)\bR&D Engineer\b",
    r"(?i)\bYes ItS Free - Bookmark It Now\b",
    r"(?i)\bCivil Engineer\b",
    r"(?i)\bHead Of It Services\b",
    r"(?i)\bWife Secretary\b",
    r"(?i)\bApplication Analyst\b",
    r"(?i)\bSr  R&D Engineer\b",
    r"(?i)\bIt Systems Manager\b",
    r"(?i)\bSecurity Analyst\b",
    r"(?i)\bData Entry Operator\b",
    r"(?i)\bMecatronics & Biomedical Engineering\b",
    r"(?i)\bBiiomedical Analyst\b",
    r"(?i)\bAdministration & Finance Director\b",
    r"(?i)\bPersonal Secretary\b",
    r"(?i)\bStudying Business Administration & Management\b",
    r"(?i)\bSite Engineer\b",
    r"(?i)\bHead Of It\b",
    r"(?i)\bIt Consultant\b",
    r"(?i)\bOffice Administrative Assistant\b",
    r"(?i)\bEnvironmental Safety Officer\b",
    r"(?i)\bPaediatrician Analyst Public Health Agency Sweden\b",
    r"(?i)\bAssistant Cook\b",
    r"(?i)\bData Curator\b",
    r"(?i)\bBusiness Administration\b",
    r"(?i)\bDirector Engineering Department\b",
    r"(?i)\bHealth Engineering Student\b",
    r"(?i)\bR&D Quality Engineer\b",
    r"(?i)\bElectrical Engineering\b",
    r"(?i)\bComputer Engineering\b",
    r"(?i)\bBeauty Market Analyst\b",
    r"(?i)\bAv Technician\b",
    r"(?i)\bData Entry Adds Watching Computer Master\b",
    r"(?i)\bIt Helpdesk\b",
    r"(?i)\bField Technician\b",
    r"(?i)\bMedical Interpreter\b",
    r"(?i)\bMedical Administrative Assistant\b",
    r"(?i)\bSenior Information Analyst\b",
    r"(?i)\bSenior Research Analyst\b",
    r"(?i)\bEstimation Engineer\b",
    r"(?i)\bApp Analyst\b",
    r"(?i)\bBiomedical Engineering\b",
    r"(?i)\bPatent Engineer\b",
    r"(?i)\bSenior Field Service Engineer\b",
    r"(?i)\bClinical Quality & Patient Safety Officer\b",
    r"(?i)\bFinancial Analyst\b",
    r"(?i)\bInvestment Analyst\b",
    r"(?i)\bBusiness Analyst\b",
    r"(?i)\bProfessor Of Electrical Engineering Dept\b",
    r"(?i)\bDigital Analyst\b",
    r"(?i)\bSupercharge Your Writing Skills With Ai - Try It Free Today\b",
    r"(?i)\bAc Technician\b",
    r"(?i)\bLaunch Your Very Own Ai App Just Like Chatgpt & Charge People For It\b",
    r"(?i)\bAssistant Director Of It & Cfh\b",
    r"(?i)\bPackaging & Device Engineer\b",
    r"(?i)\bTesting Commissioning Engineer\b",
    r"(?i)\bData EntryWork Assignment\b",
]

# Exact matches that should be updated
non_medical_staff_exact_matches = {
    'Non-medical Staff',
    "Non Medical Staff",
    "Non Med Staff",
    "Non Healthcare Staff",
    "Non Clinical Staff",
    "Non Medical Personnel",
    "Administrative Staff",
    "Hospital Administrative Staff",
    "Medical Office Staff",
    "Healthcare Support Staff",
    "Non Medial Staff",
    "None Medical Staff",
    "Non Medicl Staff",
    "Non Medicall Staff",
    "Non Medicia Staff",
    "Non Mdical Staff",
    "Non Meducal Staff",
    "Nonn Medical Staff",
    "Non Medikal Staff",
    "Non Meddical Staff",
    "Personal No Médico",
    "Empleado No Médico",
    "Trabajador No Médico",
    "Staff No Clínico",
    "Personal Administrativo de Salud",
    "Non Medical Assistant",
    "Medical Receptionist",
    "Medical Secretary",
    "Hospital Clerk",
    "Healthcare Administrative Staff",
    "Medical Support Staff",
    "Administrative Employee",
    "Staff",
    "Admin",
    "Administrator",
    'ADMINISTRATOR',
    'Engineer',
    'It',
    'Online Work',
    'Engineer',
    'engineer',
    'Secretary',
    'secretary',
    'Facial Aesthetics Administrative Support',
    'Manager Facial Aesthetics Administrative Support',
    'Non-Medical Staff',
    'Graphic Installer',
    'Stand Builder',
    'Technician',
    'technician',
    'Guest',
    'guest',
    'Escort for attendee',
}

# # Define patterns (these should NOT be changed)
# non_medical_staff_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

non_medical_staff_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Sales Technician',
    'Sales Administrator',
    'Administrative coordinator',
    'Executive Assistant To Cao & Physician Liaison',
    'Executive Administrative Assistant To The Chief Executive Officer & Dental Manager',
    'Epic Resolute Hospital Billing & Physician Billing Senior Analyst',
    'Physician & Professional Clinic Talent Acquisition Specialist',
    'Dental Administrative Assistant',
    'Administrative Assistant Dental Department',
    'Executive Assistant Dermatology',
    'Physicians Administration',
    'Division Senior Sales Manager Administration L Oreal Dermatological Beauty',
    'Executive Assistant To Chief Commercial Officer Dental & Specialty Markets',
    'Administrative Assistant General Surgery',
}

# Create a mask for Non medical Staff
mask_non_medical_staff = df['speciality'].str.contains('|'.join(non_medical_staff_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(non_medical_staff_exact_matches)

# mask_non_medical_staff_exclusions = df['speciality'].str.contains(non_medical_staff_exclusions, case=False, na=False, regex=True)
mask_non_medical_staff_exclusions = df['speciality'].isin(non_medical_staff_exclusions)

# Final mask: Select Non medical Staff
mask_non_medical_staff_final = mask_non_medical_staff & ~mask_non_medical_staff_exclusions

# Store the original values that will be replaced
original_non_medical_staff_values = df.loc[mask_non_medical_staff_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_non_medical_staff_final, 'speciality'] = 'Non medical Staff'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Non medical Staff", 'green'))
print(df.loc[mask_non_medical_staff_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_non_medical_staff_values = df.loc[mask_non_medical_staff_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Non medical Staff", "cyan"))
for original_non_medical_staff_value in original_non_medical_staff_values:
    print(f"✅ {original_non_medical_staff_value} → Non medical Staff")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Non medical Staff:", 'red'))
print(grouped_non_medical_staff_values)

# Print summary
matched_count_non_medical_staff = mask_non_medical_staff_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Non medical Staff: "
        f"{matched_count_non_medical_staff}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Licensed Practical Nurse (LPN) related titles

LPN_variants = [
    r"(?i)\bLicensed\s?Practical\s?Nurse\s?(LPN)?\b",
    r"(?i)\bPractical\s?Nurse\s?(LPN)?\b"
    r"(?i)\bLPN\b",
    r"(?i)\bLicensed\s?Nurse\s?(LPN)?\b",
    r"(?i)\b(LPN)\b",
    r"(?i)\bNursing\s?Assistant\s?(LPN)?\b",

    # Misspellings and case errors
    r"(?i)\bLicensd\s?Practical\s?Nurse\b",
    r"(?i)\bLicsensed\s?Practical\s?Nurse\b",
    r"(?i)\bLicensed\s?Pratical\s?Nurse\b",
    r"(?i)\bLicenced\s?Practical\s?Nurse\b",
    r"(?i)\bLicensed\s?Practical\s?Ners\b",
    r"(?i)\bLiceneced\s?Practical\s?Nurse\b",

    # Spanish variants
    r"(?i)\bEnfermero\s?Práctico\s?Licenciado\b",
    r"(?i)\bEnfermera\s?Práctica\s?Licenciada\b",
    r"(?i)\bEnfermero\s?Práctico\s?(LPN)?\b",
    r"(?i)\bEnfermera\s?Práctica\s?(LPN)?\b",
    r"(?i)\bAuxiliar\s?De\s?Enfermería\s?Licenciado\b",

    # Other possible variations
    r"(?i)\bLicensed\s?Practical\s?Nursing\s?Assistant\b",
    r"(?i)\bLPN\s?Assistant\b",
    r"(?i)\bLicensed\s?Practical\s?Health\s?Assistant\b",
    r"(?i)\bLPN\s?Nurse\b",
    r"(?i)\bPractical\s?Nursing\s?Technician\b",
    r"(?i)\bLPN\s?Technician\b",
    r"(?i)\bPractical\s?Nurse\s?Technician\b",

    r"(?i)\bLPN\b",
    r"(?i)\bLicensed Practical Nurse\b",
]

# Exact matches that should be updated
LPN_exact_matches = {
    "Licensed Practical Nurse (LPN)",
    "Licensed Practical Nurse",
    "LPN",
    "Practical Nurse (LPN)",
    "Licensed Nurse (LPN)",
    "Registered Nurse (LPN)",
    "Nurse (LPN)",
    "Nursing Assistant (LPN)",
    # Misspellings and case errors
    "Licensd Practical Nurse",
    "Licsensed Practical Nurse",
    "Licensed Pratical Nurse",
    "Licenced Practical Nurse",
    "Licensed Practical Ners",
    "Liceneced Practical Nurse",
    # Spanish variants
    "Enfermero Práctico Licenciado",
    "Enfermera Práctica Licenciada",
    "Enfermero Práctico (LPN)",
    "Enfermera Práctica (LPN)",
    "Auxiliar De Enfermería Licenciado",
    # Other possible variations
    "Licensed Practical Nursing Assistant",
    "LPN Assistant",
    "Licensed Practical Health Assistant",
    "LPN Nurse",
    "Practical Nursing Technician",
    "LPN Technician",
    "Practical Nurse Technician",
    'Registered Practical Nurse',
}

# Define patterns (these should NOT be changed)
LPN_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Licensed Practical Nurse (LPN)
mask_LPN = df['speciality'].str.contains('|'.join(LPN_variants), case = False, na = False, regex = True) | \
                            df['speciality'].isin(LPN_exact_matches)
mask_LPN_exclusions = df['speciality'].isin(LPN_exclusions)

# Final mask: Select Licensed Practical Nurse (LPN)
mask_LPN_final = mask_LPN & ~mask_LPN_exclusions

# Store the original values that will be replaced
original_LPN_values = df.loc[mask_LPN_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_LPN_final, 'speciality'] = 'Licensed Practical Nurse (LPN)'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Licensed Practical Nurse (LPN)", 'green'))
print(df.loc[mask_LPN_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_LPN_values = df.loc[mask_LPN_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Licensed Practical Nurse (LPN)", "cyan"))
for original_LPN_value in original_LPN_values:
    print(f"✅ {original_LPN_value} → Licensed Practical Nurse (LPN)")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Licensed Practical Nurse (LPN):", 'red'))
print(grouped_LPN_values)

# Print summary
matched_count_LPN = mask_LPN_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Licensed Practical Nurse (LPN): "
        f"{matched_count_LPN}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Product Project Manager related titles

project_manager_variants = [
    # Standard Titles & Variants
    r"(?i)\bProduct Project Manager\b",
    r"(?i)\bProduct & Project Manager\b",
    r"(?i)\bProduct-Project Manager\b",
    r"(?i)\bProduct / Project Manager\b",
    r"(?i)\bProductProject Manager\b",
    r"(?i)\bProduct Manager\b",
    r"(?i)\bProject Manager\b",
    r"(?i)\bExport Manager\b",
    r"(?i)\bProject Engineer\b",
    r"(?i)\bProducts\b",
    r"(?i)\bProduct Specialist\b",
    r"(?i)\bHead Of Projects\b",
    r"(?i)\bProdact Manager\b",
    r"(?i)\bPurchases Manager\b",
    r"(?i)\bDirecteur Des Projets Strategiques\b",
    r"(?i)\bJr Pdrocut Manager\b",
    r"(?i)\bChargee De Projets\b",
    r"(?i)Projects",
    r"(?i)Projets",
    r"(?i)Product",
    r"(?i)Project",
    r"(?i)\bProject Executive\b",
    r"(?i)\bChargee De Developpement Produit\b",
    r"(?i)Produit",
    r"(?i)Porject",
    r"(?i)\bPorject Support Manager\b",
    r"(?i)\bProjektmanager\b",
    r"(?i)Projekt",
    r"(?i)\bCharge De Programmes\b",
    r"(?i)\bCreator Of Brand Navi Natural Magic\b",
    r"(?i)\bProduct Manager Botox\b",

    # Misspellings & Typographical Errors
    r"(?i)\bProduct Proyect Manager\b",
    r"(?i)\bProduct Projet Manager\b",
    r"(?i)\bProduct Porject Manager\b",
    r"(?i)\bProduct Projct Manager\b",
    r"(?i)\bProduct Proyect Maneger\b",
    r"(?i)\bProduct Projject Managger\b",
    r"(?i)\bProduct Pojrect Manager\b",
    r"(?i)\bProduct Proyect Lead\b",

    # Case Variations
    r"(?i)\bPRODUCT PROJECT MANAGER\b",
    r"(?i)\bproduct project manager\b",
    r"(?i)\bProDuct PRoject ManAger\b",
    r"(?i)\bprOduCt pRojeCT manaGER\b",

    # Spanish Variants
    r"(?i)\bGerente de Proyecto de Producto\b",
    r"(?i)\bGestor de Proyectos de Producto\b",
    r"(?i)\bAdministrador de Proyectos de Producto\b",
    r"(?i)\bResponsable de Proyecto y Producto\b",
    r"(?i)\bCoordinador de Producto y Proyecto\b",
    r"(?i)\bLíder de Proyecto y Producto\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bProduct Proyect Gerente\b",
    r"(?i)\bProduct Project Coordinador\b",
    r"(?i)\bProducto y Proyecto Manager\b",
    r"(?i)\bProduct y Project Manager\b",
    r"(?i)\bProyect Manager\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bSenior Product Project Manager\b",
    r"(?i)\bLead Product Project Manager\b",
    r"(?i)\bHead of Product and Project Management\b",
    r"(?i)\bChief Product & Project Officer\b",
    r"(?i)\bGlobal Product Project Manager\b",
    r"(?i)\bProduct & Project Director\b",
    r"(?i)\bProduct/Project Coordinator\b",
    r"(?i)\bProduct Project Supervisor\b",
    r"(?i)\bProject Director\b",
    r"(?i)\bProject Coordinator\b",
    r"(?i)\bIfbprodact Development Officer\b",
    r"(?i)\bIfbprodact Development Officer\b",
]

# Exact matches that should be updated
project_manager_exact_matches = {
    "Product Project Manager",
    "Product & Project Manager",
    "Product-Project Manager",
    "Product / Project Manager",
    "ProductProject Manager",
    "Product Manager",
    "Project Manager",
    "Product Proyect Manager",
    "Product Projet Manager",
    "Product Porject Manager",
    "Product Projct Manager",
    "Product Proyect Maneger",
    "Product Projject Managger",
    "Product Pojrect Manager",
    "Product Proyect Lead",
    "Gerente de Proyecto de Producto",
    "Gestor de Proyectos de Producto",
    "Administrador de Proyectos de Producto",
    "Responsable de Proyecto y Producto",
    "Coordinador de Producto y Proyecto",
    "Líder de Proyecto y Producto",
    "Product Proyect Gerente",
    "Product Project Coordinador",
    "Producto y Proyecto Manager",
    "Product y Project Manager",
    "Senior Product Project Manager",
    "Lead Product Project Manager",
    "Head of Product and Project Management",
    "Chief Product & Project Officer",
    "Global Product Project Manager",
    "Product & Project Director",
    "Product/Project Coordinator",
    "Product Project Supervisor",
    "Product Specialist",
    "Project Director",
    'Service Development',
}

# # Define patterns (these should NOT be changed)
# project_manager_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

project_manager_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Product Project Manager
mask_project_manager = df['speciality'].str.contains('|'.join(project_manager_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(project_manager_exact_matches)

# mask_project_manager_exclusions = df['speciality'].str.contains(project_manager_exclusions, case=False, na=False, regex=True)
mask_project_manager_exclusions = df['speciality'].isin(project_manager_exclusions)

# Final mask: Select Product Project Manager
mask_project_manager_final = mask_project_manager & ~mask_project_manager_exclusions

# Store the original values that will be replaced
original_project_manager_values = df.loc[mask_project_manager_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_project_manager_final, 'speciality'] = 'Product Project Manager'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Product Project Manager", 'green'))
print(df.loc[mask_project_manager_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_project_manager_values = df.loc[mask_project_manager_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Product Project Manager", "cyan"))
for original_project_manager_value in original_project_manager_values:
    print(f"✅ {original_project_manager_value} → Product Project Manager")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Product Project Manager:", 'red'))
print(grouped_project_manager_values)

# Print summary
matched_count_project_manager = mask_project_manager_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Product Project Manager: "
        f"{matched_count_project_manager}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Neonatologist related titles

neonatologist_variants = [
   # Standard Titles & Abbreviations
    r"(?i)\bNeonatologist\b",
    r"(?i)\bNeonatal\s?Doctor\b",
    r"(?i)\bNeonatal\s?Specialist\b",
    r"(?i)\bNeonatology\s?Doctor\b",
    r"(?i)\bNeonatology\s?Specialist\b",
    r"(?i)\bConsultant\s?Neonatologist\b",
    r"(?i)\bSenior\s?Neonatologist\b",
    r"(?i)\bNeonatal\s?Physician\b",
    r"(?i)\bNeonatologist\s?Specialist\b",
    r"(?i)\bNeonatology\b",

    # Misspellings & Typographical Errors
    r"(?i)\bNeonotologist\b",
    r"(?i)\bNeonatoligist\b",
    r"(?i)\bNeonatoligist\b",
    r"(?i)\bNeonatoligist\b",
    r"(?i)\bNeonatogist\b",
    r"(?i)\bNeonoligist\b",
    r"(?i)\bNeonatoligist\b",
    r"(?i)\bNeonotoligist\b",
    r"(?i)\bNenoatologist\b",
    r"(?i)\bNeonologist\b",
    r"(?i)\bNeonlogist\b",
    r"(?i)\bNeonologist\b",

    # Case Variations
    r"(?i)\bneonatologist\b",
    r"(?i)\bNeonatologist\b",
    r"(?i)\bNEONATOLOGIST\b",
    r"(?i)\bNeonaToLogist\b",
    r"(?i)\bNeonAtologist\b",

    # Spanish Variants
    r"(?i)\bNeonatólogo\b",
    r"(?i)\bMédico\s?Neonatólogo\b",
    r"(?i)\bEspecialista\s?en\s?Neonatología\b",
    r"(?i)\bDoctor\s?en\s?Neonatología\b",
    r"(?i)\bConsultor\s?Neonatólogo\b",
    r"(?i)\bNeonatología\b",

    # Other Possible Variations (Including Doctor/Specialist Titles)
    r"(?i)\bNeonatal\s?Physician\b",
    r"(?i)\bNeonatal\s?Expert\b",
    r"(?i)\bPediatric\s?Neonatologist\b",
    r"(?i)\bNewborn\s?Specialist\b",
    r"(?i)\bPremature\s?Care\s?Specialist\b",
    r"(?i)\bNeonatal\s?Intensive\s?Care\s?Doctor\b",
    r"(?i)\bNeonatology\s?Expert\b",
]

# Exact matches that should be updated
neonatologist_exact_matches = {
    "Neonatologist",
    "Neonatal Doctor",
    "Neonatal Specialist",
    "Neonatology Doctor",
    "Neonatology Specialist",
    "Consultant Neonatologist",
    "Senior Neonatologist",
    "Neonatal Physician",
    "Neonatologist Specialist",
    "Neonatology",
    "Neonotologist",
    "Neonatoligist",
    "Neonatoligist",
    "Neonatogist",
    "Neonoligist",
    "Neonotoligist",
    "Nenoatologist",
    "Neonologist",
    "Neonlogist",
    "Neonatólogo",
    "Médico Neonatólogo",
    "Especialista en Neonatología",
    "Doctor en Neonatología",
    "Consultor Neonatólogo",
    "Neonatología",
    "Neonatal Physician",
    "Neonatal Expert",
    "Pediatric Neonatologist",
    "Newborn Specialist",
    "Premature Care Specialist",
    "Neonatal Intensive Care Doctor",
    "Neonatology Expert",
}

# # Define patterns (these should NOT be changed)
# neonatologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

neonatologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Neonatologist
mask_neonatologist = df['speciality'].str.contains('|'.join(neonatologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(neonatologist_exact_matches)

# mask_neonatologist_exclusions = df['speciality'].str.contains(neonatologist_exclusions, case=False, na=False, regex=True)
mask_neonatologist_exclusions = df['speciality'].isin(neonatologist_exclusions)

# Final mask: Select Neonatologist
mask_neonatologist_final = mask_neonatologist & ~mask_neonatologist_exclusions

# Store the original values that will be replaced
original_neonatologist_values = df.loc[mask_neonatologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_neonatologist_final, 'speciality'] = 'Neonatologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Neonatologist", 'green'))
print(df.loc[mask_neonatologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_neonatologist_values = df.loc[mask_neonatologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Neonatologist", "cyan"))
for original_neonatologist_value in original_neonatologist_values:
    print(f"✅ {original_neonatologist_value} → Neonatologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Neonatologist:", 'red'))
print(grouped_neonatologist_values)

# Print summary
matched_count_neonatologist = mask_neonatologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Neonatologist: "
        f"{matched_count_neonatologist}",
        'red'))

# Define regex patterns for Neurologist related titles

neurologist_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bNeurologist\b",
    r"(?i)\bNeuro\s?Doctor\b",
    r"(?i)\bNeuro\s?Specialist\b",
    r"(?i)\bNeurology\s?Doctor\b",
    r"(?i)\bNeurology\s?Specialist\b",
    r"(?i)\bConsultant\s?Neurologist\b",
    r"(?i)\bSenior\s?Neurologist\b",
    r"(?i)\bNeurological\s?Physician\b",
    r"(?i)\bNeuroscience\b",

    # Misspellings & Typographical Errors
    r"(?i)\bNurologist\b",
    r"(?i)\bNeorologist\b",
    r"(?i)\bNeuroligist\b",
    r"(?i)\bNeurlogist\b",
    r"(?i)\bNeoroligist\b",
    r"(?i)\bNeurollogist\b",
    r"(?i)\bNeurogist\b",
    r"(?i)\bNeuorlogist\b",
    r"(?i)\bNuerologist\b",
    r"(?i)\bNeurologits\b",
    r"(?i)\bNeurlgist\b",
    r"(?i)\bNeurologst\b",
    r"(?i)\bNeroligist\b",
    r"(?i)\bNeurlolgist\b",

    # Case Variations
    r"(?i)\bneurologist\b",
    r"(?i)\bNeurologist\b",
    r"(?i)\bNEUROLOGIST\b",
    r"(?i)\bNeuroLogist\b",
    r"(?i)\bNeurolOgist\b",

    # Spanish Variants
    r"(?i)\bNeurólogo\b",
    r"(?i)\bMédico\s?Neurólogo\b",
    r"(?i)\bEspecialista\s?en\s?Neurología\b",
    r"(?i)\bDoctor\s?en\s?Neurología\b",
    r"(?i)\bConsultor\s?Neurólogo\b",
    r"(?i)\bNeurocientífico\b",

    # Other Possible Variations (Including Doctor/Specialist Titles)
    r"(?i)\bNeuroscientist\b",
    r"(?i)\bNeuro\s?Physician\b",
    r"(?i)\bNeurosurgery\s?Specialist\b",
    r"(?i)\bBrain\s?Specialist\b",
    r"(?i)\bNeuromedicine\s?Expert\b",
    r"(?i)\bNeurology\b",
]

# Exact matches that should be updated
neurologist_exact_matches = {
    "Neurologist",
    "Neuro Doctor",
    "Neuro Specialist",
    "Neurology Doctor",
    "Neurology Specialist",
    "Consultant Neurologist",
    "Senior Neurologist",
    "Neurological Physician",
    "Nurologist",
    "Neorologist",
    "Neuroligist",
    "Neurlogist",
    "Neoroligist",
    "Neurollogist",
    "Neurogist",
    "Neuorlogist",
    "Nuerologist",
    "Neurologits",
    "Neurlgist",
    "Neurologst",
    "Neroligist",
    "Neurlolgist",
    "Neurólogo",
    "Médico Neurólogo",
    "Especialista en Neurología",
    "Doctor en Neurología",
    "Consultor Neurólogo",
    "Neurocientífico",
    "Neuroscientist",
    "Neuro Physician",
    "Neurosurgery Specialist",
    "Brain Specialist",
    "Neuromedicine Expert",
    'Neurosurgeon',
    'Neuro Rehab',
}

# # Define patterns (these should NOT be changed)
# neurologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

neurologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Physician Assistant Neurology & Pain Management',
}

# Create a mask for Neurologist
mask_neurologist = df['speciality'].str.contains('|'.join(neurologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(neurologist_exact_matches)

# mask_neurologist_exclusions = df['speciality'].str.contains(neurologist_exclusions, case=False, na=False, regex=True)
mask_neurologist_exclusions = df['speciality'].isin(neurologist_exclusions)

# Final mask: Select Neurologist
mask_neurologist_final = mask_neurologist & ~mask_neurologist_exclusions

# Store the original values that will be replaced
original_neurologist_values = df.loc[mask_neurologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_neurologist_final, 'speciality'] = 'Neurologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Neurologist", 'green'))
print(df.loc[mask_neurologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_neurologist_values = df.loc[mask_neurologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Neurologist", "cyan"))
for original_neurologist_value in original_neurologist_values:
    print(f"✅ {original_neurologist_value} → Neurologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Neurologist:", 'red'))
print(grouped_neurologist_values)

# Print summary
matched_count_neurologist = mask_neurologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Neurologist: "
        f"{matched_count_neurologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Sports Medicine Physician related titles

sports_med_variants = [
    # Standard Titles & Variants
    r"(?i)\bSports Medicine Physician\b",  # General term
    r"(?i)\bSports Medicine Specialist\b",  # Specialist in sports medicine
    r"(?i)\bSports Doctor\b",  # General term for sports-focused doctor
    r"(?i)\bSports Physician\b",  # Alternate term for sports-focused doctor
    r"(?i)\bSports Medicine Doctor\b",  # Another variation for a sports-focused physician
    r"(?i)\bSports Medicine\b",  # General term

    # Misspellings & Typographical Errors
    r"(?i)\bSport Medicine Physician\b",  # Common misspelling
    r"(?i)\bSport Medicine Specialist\b",  # Misspelling of "Sports"
    r"(?i)\bSports Medecine Physician\b",  # Misspelling of "Medicine"
    r"(?i)\bSports Mediine Physician\b",  # Typo with double 'i'

    # Case Variations
    r"(?i)\bSPORTS MEDICINE PHYSICIAN\b",  # Uppercase variation
    r"(?i)\bsports medicine physician\b",  # Lowercase variation
    r"(?i)\bSpOrTs MeDiCiNe PhYsIcIaN\b",  # Mixed case variation

    # Spanish Variants
    r"(?i)\bMédico de Medicina Deportiva\b",  # General term for Sports Medicine Physician
    r"(?i)\bEspecialista en Medicina Deportiva\b",  # Specialist in Sports Medicine
    r"(?i)\bMédico Deportivo\b",  # Sports doctor in Spanish
    r"(?i)\bFisioterapeuta Deportivo\b",  # Sports physiotherapist (closely related)
    r"(?i)\bMédico de Deporte\b",  # Another variant for sports physician
    r"(?i)\bMedicina del Deporte\b",  # Sports Medicine as a field (generic)
    r"(?i)\bMedicina Deportiva\b",  # General term for Sports Medicine Physician

    # Hybrid Spanish-English Variants
    r"(?i)\bSports Médico\b",  # Mixed term
    r"(?i)\bSports Médico Deportivo\b",  # Mixed term

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bSports Medicine Specialist Physician\b",  # Specialist term
    r"(?i)\bSports Medicine Expert\b",  # Expert term for sports medicine
    r"(?i)\bSports Physician Specialist\b",  # Specialist form of physician
    r"(?i)\bSports Medicine Consultant\b",  # Consulting variant
    r"(?i)\bSports Rehabilitation Doctor\b",  # Related rehabilitation term
    r"(?i)\bSports Injury Specialist\b",  # Related to injury management in sports
    r"(?i)\bMedico Esportista\b",
    r"(?i)Esportista\b",
    r"(?i)\bGym Ecology\b",
]

# Exact matches that should be updated
sports_med_exact_matches = {
    "Sports Medicine Physician",
    "Sports Medicine Specialist",
    "Sports Doctor",
    "Sports Physician",
    "Sports Medicine Doctor",
    "Sport Medicine Physician",
    "Sport Medicine Specialist",
    "Sports Medecine Physician",
    "Sports Mediine Physician",
    "SPORTS MEDICINE PHYSICIAN",
    "sports medicine physician",
    "SpOrTs MeDiCiNe PhYsIcIaN",
    "Médico de Medicina Deportiva",
    "Especialista en Medicina Deportiva",
    "Médico Deportivo",
    "Fisioterapeuta Deportivo",
    "Médico de Deporte",
    "Medicina del Deporte",
    "Sports Médico",
    "Sports Médico Deportivo",
    "Sports Medicine Specialist Physician",
    "Sports Medicine Expert",
    "Sports Physician Specialist",
    "Sports Medicine Consultant",
    "Sports Rehabilitation Doctor",
    "Sports Injury Specialist",
    'Family Sports',
}

# # Define patterns (these should NOT be changed)
# sports_med_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

sports_med_exclusions = {
    'Resident', 'resident', 'student', 'Trainee', 'Resident Doctor', 'Resident ooPhysician',
    'Intern', 'intern', 'Medical Intern', 'Fellow', 'fellow', 'Clinical Fellow', 'Medical Student',
    'Clinical Trainee', 'Trainee Doctor', 'Trainee Physician', 'Junior Doctor', 'Postgraduate Trainee',
    'Aesthetic Fellow', 'Aesthetic Trainee', 'Aesthetic Medicine Fellow', 'Aesthetic Resident'
}

# Create a mask for Sports Medicine Physician
mask_sports_med = df['speciality'].str.contains('|'.join(sports_med_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(sports_med_exact_matches)

# mask_sports_med_exclusions = df['speciality'].str.contains(sports_med_exclusions, case=False, na=False, regex=True)
mask_sports_med_exclusions = df['speciality'].isin(sports_med_exclusions)

# Final mask: Select Sports Medicine Physician
mask_sports_med_final = mask_sports_med & ~mask_sports_med_exclusions

# Store the original values that will be replaced
original_sports_med_values = df.loc[mask_sports_med_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_sports_med_final, 'speciality'] = 'Sports Medicine Physician'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Sports Medicine Physician", 'green'))
print(df.loc[mask_sports_med_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_sports_med_values = df.loc[mask_sports_med_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Sports Medicine Physician", "cyan"))
for original_sports_med_value in original_sports_med_values:
    print(f"✅ {original_sports_med_value} → Sports Medicine Physician")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Sports Medicine Physician:", 'red'))
print(grouped_sports_med_values)

# Print summary
matched_count_sports_med = mask_sports_med_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Sports Medicine Physician: "
        f"{matched_count_sports_med}",
        'red'))